from collections import deque
import csv
import datetime
from pathlib import Path
import threading
import typing

from lxml import etree

from tgtools.parsers.events.event import Event, Token
from tgtools import Err
import tgtools.utils.ioutils.iocsv as io_csv
from tgtools.utils.ioutils.iogen import confirm_exists
from tgtools.utils.timefunc import datetime_to_string3, string_to_datetime


class Events(list):
    """ A processor/parser for the XML response of the **get-events** RPC, including:

         * separating to individual events, sorting chronologically, and parsing of each into :class:`~tgtools.parsers.events.event.Event`,
         * appending to an existing csv file, ensuring no replication.

         This class is an extension of `list <https://docs.python.org/3/library/stdtypes.html#list>`_.

         Instantiation is typically via the class method :meth:`from_xml`.
    """

    ONE_SECOND = datetime.timedelta(seconds=1)

    def __init__(self):
        """
            :meta private:
        """
        super().__init__()
        #: List of errors
        self.errors: list[Err] = []

    def __str__(self):
        info = f"{__class__.__name__}:\n"
        for item in self:
            info += f"\t{item}\n"
        return info

    def __eq__(self, other):
        return all(a == b for (a, b) in zip(self, other))

    @classmethod
    def from_csv(cls, filepath: Path) -> typing.Self:
        """ Create a class instance by reading parsed events from csv file.

            :param filepath: Path to csv file
            :type filepath: pathlib.Path
            :return: Class instance.
            """
        events_raw = io_csv.read_csv(filepath)
        events = cls()
        events += [Event.from_dict(event) for event in events_raw]
        return events

    @classmethod
    def from_xml(cls, xml: str, prefix_dict: dict[str, str] | None = None) -> typing.Self:
        """ Create class instance by parsing the xml output of the **get-events** RPC.

         :param xml: The xml string output returned by the **get-events** RPC.
         :type xml: str
         :param prefix_dict: an optional arbitrary dictionary, prepended to each parsed event (default: None).
         :type prefix_dict: dict | None
         :return: a class instance.

        """
        events = cls()
        xml_etree = events.calc_xml_etree(xml)
        events.parse_xml_etree(xml_etree, prefix_dict)
        return events

    def calc_xml_etree(self, xml: str) -> etree.ElementTree:
        """ Convert the xml output of the **get-events** RPC into an `ElementTree <https://lxml.de/tutorial.html>`_
            (thereby validating xml syntax).
            This method is not typically called directly, but rather implicitly by calling :meth:`from_xml`.

            :param xml: The xml output of the **get-events** RPC.
            :type xml: str
            :return: An etree representation of the xml input.
            :rtype: lxml.ElementTree
        """

        try:
            xml_etree = etree.fromstring(xml.encode('utf-8'))
        except (etree.LxmlSyntaxError, AttributeError):
            error = Err(f"{type(self).__name__}()", "Cannot convert xml string input to lxml.etree")
            self.errors.append(error)
            xml_etree = etree.fromstring('<None/>')
        return xml_etree

    def parse_xml_etree(self, xml_etree: etree.ElementTree, prefix_dict: dict[str, str] | None = None):
        """ Parse each element of ElementTree to :class:`~tgtools.parsers.events.event.Event`, and append
            to class instance. Finally, sort chronologically.
            This method is not typically called directly, but rather implicitly by calling :meth:`from_xml`.

            :param xml_etree: an ElementEtree representing the xml output of the **get-events** RPC.
            :type xml_etree: etree.ElementTree
            :param prefix_dict: An arbitrary dictionary, typically identifying the source radio and computer's timestamp (default: None).
            :type prefix_dict: dict[str, str] | None
        """

        for element in xml_etree.iterfind('.//{*}events'):
            event_index = int(element.findtext('{*}index', default=''))
            event_str = element.findtext('{*}event', default='')
            event = Event.from_xml(event_str, event_index, prefix_dict)
            if event.errors:
                self.errors += event.errors
            else:
                self.append(event)
        self.sort(key=lambda x: x[Token.index])
        return None

    def append_csv(self, path_file: Path, threading_lock: threading.Lock | None = None):
        """ Save class instance (list of events) to a csv file. If the file does not exist, it is created.
            But if the file does already exist (includes previous events), then only the new (not yet saved)
            events are appended. This avoids duplication in the output csv file.

            :param path_file: Path to csv file.
            :type path_file: pathlib.Path
            :param threading_lock: Threading lock, if needing to ensure method is thread-safe (Default: None).
            :type threading_lock:  threading.Lock | None

        """
        if confirm_exists(path_file):   # Append existing file
            # Read existing files into a fixed-length stack
            last_saved_events_stack = deque(maxlen=len(self))
            if threading_lock:
                threading_lock.acquire()
            with path_file.open('rt', newline='') as csvfile:
                reader = csv.reader(csvfile)
                fieldnames = next(reader)
                for row in reader:
                    last_saved_events_stack.append(row)
            if threading_lock:
                threading_lock.release()
            # Last event already saved in csv file
            last_saved_event = dict(zip(fieldnames, row))

            # Discard from stack historical events
            for _ in range(len(last_saved_events_stack)):
                if [dict(zip(fieldnames, row)) for row in last_saved_events_stack] == self:
                    break
                last_saved_events_stack.popleft()
            len_remaining_stack = len(last_saved_events_stack)
            # If stack is empty, then some events may be missing. Add a suitable disclaimer
            if len_remaining_stack == 0:
                last_timestamp = string_to_datetime(last_saved_event[Token.timestamp])
                marker_event = {key: '' for key in last_saved_event.keys()}
                marker_event[Token.index] = '-1'
                marker_event[Token.timestamp] = datetime_to_string3(last_timestamp + self.ONE_SECOND)
                marker_event[Token.id] = '-1'
                marker_event[Token.msg] = '... possibly missing some records here ...'
                self.insert(0, marker_event)
            # Append to csv file only the new events
            io_csv.write_csv(self[len_remaining_stack:], path_file, append=True, threading_lock=threading_lock)
        else:   # Create new file
            io_csv.write_csv(self, path_file, append=False, threading_lock=threading_lock)


if __name__ == "__main__":
    xml = '<rpc-reply xmlns="urn:ietf:params:xml:ns:netconf:base:1.0" xmlns:nc="urn:ietf:params:xml:ns:netconf:base:1.0" message-id="urn:uuid:fb6a10dc-1097-4e6d-8cb7-7524fc94d327"><events xmlns="http://siklu.com/yang/tg/events"><index>0</index><event>2024-10-13 23:31:03.784, 1388,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>1</index><event>2024-10-13 23:56:02.304, 1389,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:24:58); Cause: LinkNegotiationFailed; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>10</index><event>2024-10-14 00:26:09.210, 1398,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>100</index><event>2024-10-14 13:24:05.585, 1488,SYSTEM, LOCAL,  RADIO,   559611 link down (was up for 00000:07:21:31); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>101</index><event>2024-10-14 13:24:30.484, 1489,SYSTEM, LOCAL,  RADIO,   559611 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 66/66; Tx/Rx Az: 24/24 deg; Tx/Rx El: 0/0 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>102</index><event>2024-10-14 13:41:18.850, 1490,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:01:16:15); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>103</index><event>2024-10-14 13:41:28.523, 1491,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>104</index><event>2024-10-14 14:09:40.627, 1492,SYSTEM, LOCAL,  RADIO,   559611 link down (was up for 00000:00:45:10); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>105</index><event>2024-10-14 14:10:12.927, 1493,SYSTEM, LOCAL,  RADIO,   559611 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 30/30; Tx/Rx Az: 28/28 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>106</index><event>2024-10-14 14:40:53.934, 1494,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:59:25); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>107</index><event>2024-10-14 14:41:11.878, 1495,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>108</index><event>2024-10-14 17:02:47.911, 1496,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:02:21:36); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>109</index><event>2024-10-14 17:02:52.058, 1497,SYSTEM, LOCAL,  RADIO,   497691 link down (was up for 00000:10:56:40); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>11</index><event>2024-10-14 00:38:46.521, 1399,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:12:37); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>110</index><event>2024-10-14 17:03:02.262, 1498,SYSTEM, LOCAL,  RADIO,   497691 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 30/30; Tx/Rx Az: 28/28 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>111</index><event>2024-10-14 17:03:21.386, 1499,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>112</index><event>2024-10-14 18:41:15.510, 1500,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:01:37:54); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>113</index><event>2024-10-14 18:41:32.717, 1501,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>114</index><event>2024-10-14 20:50:28.307, 1502,SYSTEM, LOCAL,  RADIO,   559611 link down (was up for 00000:06:40:15); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>115</index><event>2024-10-14 20:50:29.667, 1503,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:02:08:56); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>116</index><event>2024-10-14 20:51:16.757, 1504,SYSTEM, LOCAL,  RADIO,   559611 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 66/30; Tx/Rx Az: 24/28 deg; Tx/Rx El: 0/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>117</index><event>2024-10-14 20:52:35.809, 1505,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>118</index><event>2024-10-14 22:02:16.792, 1506,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:01:09:40); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>119</index><event>2024-10-14 22:02:34.757, 1507,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>12</index><event>2024-10-14 00:39:04.117, 1400,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>120</index><event>2024-10-14 22:02:35.121, 1508,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:00:00); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>121</index><event>2024-10-14 22:02:51.776, 1509,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>122</index><event>2024-10-15 06:56:28.520, 1510,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:08:53:36); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>123</index><event>2024-10-15 06:56:46.102, 1511,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>124</index><event>2024-10-15 07:25:00.407, 1512,SYSTEM, LOCAL,  RADIO,   559611 link down (was up for 00000:10:33:43); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>125</index><event>2024-10-15 07:25:33.244, 1513,SYSTEM, LOCAL,  RADIO,   559611 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 66/30; Tx/Rx Az: 24/28 deg; Tx/Rx El: 0/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>126</index><event>2024-10-15 09:04:49.827, 1514,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:02:08:03); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>127</index><event>2024-10-15 09:05:07.284, 1515,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>128</index><event>2024-10-15 10:02:41.255, 1516,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:57:33); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>129</index><event>2024-10-15 10:02:59.372, 1517,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>13</index><event>2024-10-14 00:40:08.208, 1401,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:01:04); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>130</index><event>2024-10-15 14:45:58.646, 1518,SYSTEM, LOCAL,  RADIO,   559611 link down (was up for 00000:07:20:25); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>131</index><event>2024-10-15 14:46:31.578, 1519,SYSTEM, LOCAL,  RADIO,   559611 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 66/30; Tx/Rx Az: 24/28 deg; Tx/Rx El: 0/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>132</index><event>2024-10-15 15:14:28.858, 1520,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:05:11:30); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>133</index><event>2024-10-15 15:16:20.344, 1521,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>134</index><event>2024-10-15 15:44:18.576, 1522,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:27:58); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>135</index><event>2024-10-15 15:44:36.415, 1523,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>136</index><event>2024-10-15 15:47:37.354, 1524,SYSTEM, LOCAL,  RADIO,   559611 link down (was up for 00000:01:01:06); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>137</index><event>2024-10-15 15:47:49.496, 1525,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:03:13); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>138</index><event>2024-10-15 15:48:01.215, 1526,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>139</index><event>2024-10-15 15:48:33.307, 1527,SYSTEM, LOCAL,  RADIO,   559611 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 66/30; Tx/Rx Az: 24/28 deg; Tx/Rx El: 0/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>14</index><event>2024-10-14 00:40:26.266, 1402,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/30; Tx/Rx Az: 20/28 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>140</index><event>2024-10-15 16:04:53.481, 1528,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:16:52); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>141</index><event>2024-10-15 16:05:11.565, 1529,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>142</index><event>2024-10-15 16:22:11.673, 1530,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:17:00); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>143</index><event>2024-10-15 16:22:22.525, 1531,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/30; Tx/Rx Az: 20/28 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>144</index><event>2024-10-15 16:50:46.766, 1532,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:28:24); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>145</index><event>2024-10-15 16:50:56.379, 1533,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>146</index><event>2024-10-15 17:20:31.849, 1534,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:29:35); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>147</index><event>2024-10-15 17:20:48.658, 1535,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>148</index><event>2024-10-15 17:37:48.840, 1536,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:17:00); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>149</index><event>2024-10-15 17:37:59.354, 1537,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>15</index><event>2024-10-14 00:54:47.554, 1403,SYSTEM, LOCAL,  RADIO,   497691 link down (was up for 00000:00:49:46); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>150</index><event>2024-10-15 19:18:51.475, 1538,SYSTEM, LOCAL,  RADIO,   559611 link down (was up for 00000:03:30:18); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>151</index><event>2024-10-15 19:19:05.010, 1539,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:01:41:05); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>152</index><event>2024-10-15 19:19:23.651, 1540,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>153</index><event>2024-10-15 19:19:45.430, 1541,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:00:21); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>154</index><event>2024-10-15 19:19:55.695, 1542,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>155</index><event>2024-10-15 19:20:07.043, 1543,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:00:11); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>156</index><event>2024-10-15 19:20:26.069, 1544,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>157</index><event>2024-10-15 19:20:57.238, 1545,SYSTEM, LOCAL,  RADIO,   559611 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 66/30; Tx/Rx Az: 24/28 deg; Tx/Rx El: 0/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>158</index><event>2024-10-15 19:22:19.122, 1546,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:01:53); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>159</index><event>2024-10-15 19:22:37.459, 1547,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>16</index><event>2024-10-14 00:54:57.244, 1404,SYSTEM, LOCAL,  RADIO,   497691 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 30/30; Tx/Rx Az: 28/28 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>160</index><event>2024-10-15 21:42:52.813, 1548,SYSTEM, LOCAL,  RADIO,   559611 link down (was up for 00000:02:21:55); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>161</index><event>2024-10-15 21:43:25.633, 1549,SYSTEM, LOCAL,  RADIO,   559611 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 66/30; Tx/Rx Az: 24/28 deg; Tx/Rx El: 0/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>162</index><event>2024-10-15 22:40:47.691, 1550,SYSTEM, LOCAL,  RADIO,   559611 link down (was up for 00000:00:57:22); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>163</index><event>2024-10-15 22:41:12.561, 1551,SYSTEM, LOCAL,  RADIO,   559611 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 30/30; Tx/Rx Az: 28/28 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>164</index><event>2024-10-16 02:27:50.685, 1552,SYSTEM, LOCAL,  RADIO,   559611 link down (was up for 00000:03:46:38); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>165</index><event>2024-10-16 02:28:24.826, 1553,SYSTEM, LOCAL,  RADIO,   559611 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 66/30; Tx/Rx Az: 24/28 deg; Tx/Rx El: 0/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>166</index><event>2024-10-16 03:38:24.460, 1554,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:08:15:47); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>167</index><event>2024-10-16 03:38:41.838, 1555,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/30; Tx/Rx Az: 20/28 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>168</index><event>2024-10-16 20:56:28.069, 1556,SYSTEM, LOCAL,  RADIO,   497691 link down (was up for 00002:03:53:28); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>169</index><event>2024-10-16 20:56:35.774, 1557,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:17:17:55); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>17</index><event>2024-10-14 01:38:20.429, 1405,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:57:54); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>170</index><event>2024-10-16 20:56:37.803, 1558,SYSTEM, LOCAL,  RADIO,   497691 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 30/30; Tx/Rx Az: 28/28 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>171</index><event>2024-10-16 21:24:57.912, 1559,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/30; Tx/Rx Az: 20/28 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>172</index><event>2024-10-17 06:50:36.167, 1560,SYSTEM, LOCAL,  RADIO,   582691 link down (was up for 00003:00:46:36); Cause: HeartbeatLossDetected; Local/Remote Sector: 2/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>173</index><event>2024-10-17 06:56:12.149, 1561,SYSTEM, LOCAL,  RADIO,   gpop link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 58/58; Tx/Rx Az: -8/-8 deg; Tx/Rx El: 0/0 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>174</index><event>2024-10-17 06:56:16.899, 1562,SYSTEM, LOCAL,  RADIO,   gpop link down (was up for 00000:00:00:04); Cause: LinkNegotiationFailed; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>175</index><event>2024-10-17 06:57:11.189, 1563,SYSTEM, LOCAL,  RADIO,   gpop link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 58/58; Tx/Rx Az: -8/-8 deg; Tx/Rx El: 0/0 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>176</index><event>2024-10-17 06:57:46.299, 1564,SYSTEM, LOCAL,  RADIO,   582691 link up; Local/Remote Sector: 2/1; Tx/Rx Beam: 36/36; Tx/Rx Az: 4/4 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>177</index><event>2024-10-17 07:01:47.815, 1565,SYSTEM, LOCAL,  SW_UPGRADE, Software download failed with error:: Burn image to not running bank failed</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>178</index><event>2024-10-17 07:15:44.018, 1566,SYSTEM, LOCAL,  SW_UPGRADE, Software download failed with error:: Burn image to not running bank failed</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>179</index><event>2024-10-19 12:57:52.561, 1567,SYSTEM, LOCAL,  RADIO,   497691 link down (was up for 00002:16:01:15); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>18</index><event>2024-10-14 01:38:29.979, 1406,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/20; Tx/Rx Az: 20/24 deg; Tx/Rx El: -10/-20 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>180</index><event>2024-10-21 09:59:05.578, 1568,SYSTEM, LOCAL,  RADIO,   588932 link down (was up for 00007:03:54:46); Cause: HeartbeatLossDetected; Local/Remote Sector: 2/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>181</index><event>2024-10-21 15:08:21.330, 1569,SYSTEM, LOCAL,  RADIO,   588932 link up; Local/Remote Sector: 2/1; Tx/Rx Beam: 64/64; Tx/Rx Az: 16/16 deg; Tx/Rx El: 0/0 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>182</index><event>2024-10-21 15:08:52.673, 1570,SYSTEM, LOCAL,  RADIO,   588932 link down (was up for 00000:00:00:31); Cause: HeartbeatLossDetected; Local/Remote Sector: 2/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>183</index><event>2024-10-21 15:10:10.004, 1571,SYSTEM, LOCAL,  RADIO,   588932 link up; Local/Remote Sector: 2/1; Tx/Rx Beam: 34/64; Tx/Rx Az: 12/16 deg; Tx/Rx El: -10/0 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>184</index><event>2024-10-21 19:59:19.923, 1572,SYSTEM, LOCAL,  RADIO,   576641 link down (was up for 00007:13:56:06); Cause: HeartbeatLossDetected; Local/Remote Sector: 1/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>185</index><event>2024-10-21 20:27:55.363, 1573,SYSTEM, LOCAL,  RADIO,   576641 link up; Local/Remote Sector: 1/1; Tx/Rx Beam: 40/40; Tx/Rx Az: -12/-12 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>186</index><event>2024-10-22 09:29:28.875, 1574,SYSTEM, LOCAL,  ETH,     eth1 link down</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>187</index><event>2024-10-22 09:29:39.961, 1575,SYSTEM, LOCAL,  ETH,     eth1 link up</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>188</index><event>2024-10-22 09:29:39.963, 1576,SYSTEM, LOCAL,  ETH,     eth1 changed from 1Gbps full-duplex to 100Mbps full-duplex</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>189</index><event>2024-10-22 09:29:46.007, 1577,SYSTEM, LOCAL,  ETH,     eth1 link down</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>19</index><event>2024-10-14 01:40:51.780, 1407,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:02:21); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>190</index><event>2024-10-22 09:29:52.056, 1578,SYSTEM, LOCAL,  ETH,     eth1 link up</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>191</index><event>2024-10-22 09:29:52.059, 1579,SYSTEM, LOCAL,  ETH,     eth1 changed from 100Mbps full-duplex to 1Gbps full-duplex</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>192</index><event>2024-10-22 10:46:20.075, 1580,SYSTEM, LOCAL,  GPS,     GPS state changed from 3D to no-fix</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>193</index><event>2024-10-22 10:46:21.077, 1581,SYSTEM, LOCAL,  GPS,     GPS state changed from no-fix to 3D</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>194</index><event>2024-10-22 11:04:35.345, 1582,SYSTEM, LOCAL,  RADIO,   588932 link down (was up for 00000:19:54:25); Cause: HeartbeatLossDetected; Local/Remote Sector: 2/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>195</index><event>2024-10-22 11:05:45.205, 1583,SYSTEM, LOCAL,  RADIO,   588932 link up; Local/Remote Sector: 2/1; Tx/Rx Beam: 64/64; Tx/Rx Az: 16/16 deg; Tx/Rx El: 0/0 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>196</index><event>2024-10-24 03:06:54.161, 1584,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00007:05:41:57); Cause: LinkNegotiationFailed; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>197</index><event>2024-10-24 03:07:20.409, 1585,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 30/30; Tx/Rx Az: 28/28 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>198</index><event>2024-10-24 04:23:08.769, 1586,SYSTEM, LOCAL,  RADIO,   588932 link down (was up for 00001:17:17:23); Cause: HeartbeatLossDetected; Local/Remote Sector: 2/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>199</index><event>2024-10-24 11:38:26.140, 1587,SYSTEM, LOCAL,  RADIO,   588932 link up; Local/Remote Sector: 2/1; Tx/Rx Beam: 34/64; Tx/Rx Az: 12/16 deg; Tx/Rx El: -10/0 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>2</index><event>2024-10-13 23:57:25.530, 1390,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>20</index><event>2024-10-14 01:41:10.190, 1408,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>21</index><event>2024-10-14 01:44:44.054, 1409,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:03:33); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>22</index><event>2024-10-14 01:44:54.118, 1410,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>23</index><event>2024-10-14 01:45:28.105, 1411,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:00:33); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>24</index><event>2024-10-14 01:45:40.220, 1412,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>25</index><event>2024-10-14 02:01:02.691, 1413,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:15:22); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>26</index><event>2024-10-14 02:01:14.230, 1414,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>27</index><event>2024-10-14 02:29:28.140, 1415,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:28:13); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>28</index><event>2024-10-14 02:29:45.356, 1416,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>29</index><event>2024-10-14 03:43:10.259, 1417,SYSTEM, LOCAL,  RADIO,   497691 link down (was up for 00000:02:48:13); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>3</index><event>2024-10-14 00:02:16.182, 1391,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:04:50); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>30</index><event>2024-10-14 03:43:29.579, 1418,SYSTEM, LOCAL,  RADIO,   497691 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 30/30; Tx/Rx Az: 28/28 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>31</index><event>2024-10-14 04:40:49.013, 1419,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:02:11:03); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>32</index><event>2024-10-14 04:41:06.113, 1420,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>33</index><event>2024-10-14 04:56:25.303, 1421,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:15:19); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>34</index><event>2024-10-14 04:56:43.477, 1422,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>35</index><event>2024-10-14 05:43:26.414, 1423,SYSTEM, LOCAL,  ETH,     eth1 link down</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>36</index><event>2024-10-14 05:43:37.503, 1424,SYSTEM, LOCAL,  ETH,     eth1 link up</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>37</index><event>2024-10-14 05:43:41.535, 1425,SYSTEM, LOCAL,  ETH,     eth1 link down</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>38</index><event>2024-10-14 05:43:43.551, 1426,SYSTEM, LOCAL,  ETH,     eth1 link up</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>39</index><event>2024-10-14 05:44:19.835, 1427,SYSTEM, LOCAL,  ETH,     eth1 link down</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>4</index><event>2024-10-14 00:02:28.379, 1392,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>40</index><event>2024-10-14 05:44:21.875, 1428,SYSTEM, LOCAL,  ETH,     eth1 link up</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>41</index><event>2024-10-14 05:53:34.292, 1429,SYSTEM, LOCAL,  RADIO,   gnode-g link down (was up for 00008:08:29:06); Cause: HeartbeatLossDetected; Local/Remote Sector: 1/4</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>42</index><event>2024-10-14 06:00:03.856, 1430,SYSTEM, LOCAL,  RADIO,   498371 link down (was up for 00008:08:31:54); Cause: HeartbeatLossDetected; Local/Remote Sector: 1/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>43</index><event>2024-10-14 06:00:06.508, 1431,SYSTEM, LOCAL,  RADIO,   552191 link down (was up for 00008:08:34:46); Cause: HeartbeatLossDetected; Local/Remote Sector: 1/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>44</index><event>2024-10-14 06:00:08.303, 1432,SYSTEM, LOCAL,  RADIO,   553901 link down (was up for 00008:08:34:32); Cause: HeartbeatLossDetected; Local/Remote Sector: 1/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>45</index><event>2024-10-14 06:00:09.855, 1433,SYSTEM, LOCAL,  RADIO,   556821 link down (was up for 00008:08:34:19); Cause: HeartbeatLossDetected; Local/Remote Sector: 1/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>46</index><event>2024-10-14 06:00:09.915, 1434,SYSTEM, LOCAL,  RADIO,   488251 link down (was up for 00008:08:35:28); Cause: HeartbeatLossDetected; Local/Remote Sector: 1/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>47</index><event>2024-10-14 06:00:12.452, 1435,SYSTEM, LOCAL,  RADIO,   567731 link down (was up for 00008:08:34:14); Cause: HeartbeatLossDetected; Local/Remote Sector: 1/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>48</index><event>2024-10-14 06:00:15.814, 1436,SYSTEM, LOCAL,  RADIO,   669601 link down (was up for 00008:08:32:39); Cause: HeartbeatLossDetected; Local/Remote Sector: 1/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>49</index><event>2024-10-14 06:00:17.802, 1437,SYSTEM, LOCAL,  RADIO,   567421 link down (was up for 00008:08:38:40); Cause: HeartbeatLossDetected; Local/Remote Sector: 2/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>5</index><event>2024-10-14 00:04:44.030, 1393,SYSTEM, LOCAL,  RADIO,   497691 link down (was up for 00000:00:52:44); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>50</index><event>2024-10-14 06:00:22.336, 1438,SYSTEM, LOCAL,  RADIO,   570881 link down (was up for 00008:07:59:52); Cause: HeartbeatLossDetected; Local/Remote Sector: 2/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>51</index><event>2024-10-14 06:00:23.623, 1439,SYSTEM, LOCAL,  RADIO,   576641 link down (was up for 00008:08:33:49); Cause: HeartbeatLossDetected; Local/Remote Sector: 1/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>52</index><event>2024-10-14 06:00:25.798, 1440,SYSTEM, LOCAL,  RADIO,   582691 link down (was up for 00008:08:37:32); Cause: HeartbeatLossDetected; Local/Remote Sector: 2/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>53</index><event>2024-10-14 06:00:33.235, 1441,SYSTEM, LOCAL,  RADIO,   608651 link down (was up for 00008:08:36:53); Cause: HeartbeatLossDetected; Local/Remote Sector: 2/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>54</index><event>2024-10-14 06:00:34.605, 1442,SYSTEM, LOCAL,  RADIO,   611211 link down (was up for 00008:08:36:38); Cause: HeartbeatLossDetected; Local/Remote Sector: 2/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>55</index><event>2024-10-14 06:00:37.949, 1443,SYSTEM, LOCAL,  RADIO,   672611 link down (was up for 00008:08:41:26); Cause: HeartbeatLossDetected; Local/Remote Sector: 2/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>56</index><event>2024-10-14 06:00:39.590, 1444,SYSTEM, LOCAL,  RADIO,   497691 link down (was up for 00000:02:17:10); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>57</index><event>2024-10-14 06:00:40.567, 1445,SYSTEM, LOCAL,  RADIO,   588932 link down (was up for 00008:08:37:14); Cause: HeartbeatLossDetected; Local/Remote Sector: 2/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>58</index><event>2024-10-14 06:00:43.185, 1446,SYSTEM, LOCAL,  RADIO,   559611 link down (was up for 00000:21:08:20); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>59</index><event>2024-10-14 06:00:44.685, 1447,SYSTEM, LOCAL,  RADIO,   551141 link down (was up for 00004:07:26:52); Cause: HeartbeatLossDetected; Local/Remote Sector: 4/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>6</index><event>2024-10-14 00:05:00.669, 1394,SYSTEM, LOCAL,  RADIO,   497691 link up; Local/Remote Sector: 3/1; </event></events><events xmlns="http://siklu.com/yang/tg/events"><index>60</index><event>2024-10-14 06:00:44.962, 1448,SYSTEM, LOCAL,  RADIO,   662111 link down (was up for 00008:08:41:46); Cause: HeartbeatLossDetected; Local/Remote Sector: 2/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>61</index><event>2024-10-14 06:00:47.785, 1449,SYSTEM, LOCAL,  RADIO,   579901 link down (was up for 00008:08:38:08); Cause: HeartbeatLossDetected; Local/Remote Sector: 4/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>62</index><event>2024-10-14 06:00:50.344, 1450,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:01:04:06); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>63</index><event>2024-10-14 06:01:04.706, 1451,SYSTEM, LOCAL,  RADIO,   679011 link down (was up for 00008:08:41:36); Cause: HeartbeatLossDetected; Local/Remote Sector: 4/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>64</index><event>2024-10-14 06:02:03.134, 1452,SYSTEM, LOCAL,  RADIO,   551141 link up; Local/Remote Sector: 4/1; Tx/Rx Beam: 40/40; Tx/Rx Az: -12/-12 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>65</index><event>2024-10-14 06:02:13.139, 1453,SYSTEM, LOCAL,  RADIO,   552191 link up; Local/Remote Sector: 1/1; Tx/Rx Beam: 20/20; Tx/Rx Az: 24/24 deg; Tx/Rx El: -20/-20 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>66</index><event>2024-10-14 06:02:34.169, 1454,SYSTEM, LOCAL,  RADIO,   559611 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 66/66; Tx/Rx Az: 24/24 deg; Tx/Rx El: 0/0 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>67</index><event>2024-10-14 06:02:49.082, 1455,SYSTEM, LOCAL,  RADIO,   567421 link up; Local/Remote Sector: 2/1; Tx/Rx Beam: 54/54; Tx/Rx Az: -24/-24 deg; Tx/Rx El: 0/0 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>68</index><event>2024-10-14 06:03:07.154, 1456,SYSTEM, LOCAL,  RADIO,   570881 link up; Local/Remote Sector: 2/1; Tx/Rx Beam: 64/64; Tx/Rx Az: 16/16 deg; Tx/Rx El: 0/0 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>69</index><event>2024-10-14 06:03:17.169, 1457,SYSTEM, LOCAL,  RADIO,   576641 link up; Local/Remote Sector: 1/1; Tx/Rx Beam: 40/40; Tx/Rx Az: -12/-12 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>7</index><event>2024-10-14 00:06:37.278, 1395,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:04:08); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>70</index><event>2024-10-14 06:03:48.185, 1458,SYSTEM, LOCAL,  RADIO,   579901 link up; Local/Remote Sector: 4/1; Tx/Rx Beam: 52/46; Tx/Rx Az: -32/-36 deg; Tx/Rx El: 0/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>71</index><event>2024-10-14 06:04:03.193, 1459,SYSTEM, LOCAL,  RADIO,   582691 link up; Local/Remote Sector: 2/1; Tx/Rx Beam: 60/36; Tx/Rx Az: 0/4 deg; Tx/Rx El: 0/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>72</index><event>2024-10-14 06:04:23.218, 1460,SYSTEM, LOCAL,  RADIO,   588932 link up; Local/Remote Sector: 2/1; Tx/Rx Beam: 64/34; Tx/Rx Az: 16/12 deg; Tx/Rx El: 0/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>73</index><event>2024-10-14 06:04:33.219, 1461,SYSTEM, LOCAL,  RADIO,   608651 link up; Local/Remote Sector: 2/1; Tx/Rx Beam: 48/48; Tx/Rx Az: -44/-44 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>74</index><event>2024-10-14 06:04:53.221, 1462,SYSTEM, LOCAL,  RADIO,   611211 link up; Local/Remote Sector: 2/1; Tx/Rx Beam: 44/44; Tx/Rx Az: -28/-28 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>75</index><event>2024-10-14 06:05:19.253, 1463,SYSTEM, LOCAL,  RADIO,   662111 link up; Local/Remote Sector: 2/1; Tx/Rx Beam: 42/56; Tx/Rx Az: -20/-16 deg; Tx/Rx El: -10/0 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>76</index><event>2024-10-14 06:05:39.261, 1464,SYSTEM, LOCAL,  RADIO,   672611 link up; Local/Remote Sector: 2/1; Tx/Rx Beam: 56/56; Tx/Rx Az: -16/-16 deg; Tx/Rx El: 0/0 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>77</index><event>2024-10-14 06:05:54.263, 1465,SYSTEM, LOCAL,  RADIO,   679011 link up; Local/Remote Sector: 4/1; Tx/Rx Beam: 36/36; Tx/Rx Az: 4/4 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>78</index><event>2024-10-14 06:06:12.273, 1466,SYSTEM, LOCAL,  RADIO,   497691 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/30; Tx/Rx Az: 20/28 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>79</index><event>2024-10-14 06:06:24.354, 1467,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>8</index><event>2024-10-14 00:06:55.179, 1396,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>80</index><event>2024-10-14 06:06:58.370, 1468,SYSTEM, LOCAL,  RADIO,   553901 link up; Local/Remote Sector: 1/1; Tx/Rx Beam: 46/46; Tx/Rx Az: -36/-36 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>81</index><event>2024-10-14 06:07:14.373, 1469,SYSTEM, LOCAL,  RADIO,   556821 link up; Local/Remote Sector: 1/1; Tx/Rx Beam: 94/2; Tx/Rx Az: -44/-44 deg; Tx/Rx El: 10/-20 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>82</index><event>2024-10-14 06:08:23.397, 1470,SYSTEM, LOCAL,  RADIO,   567731 link up; Local/Remote Sector: 1/1; Tx/Rx Beam: 52/46; Tx/Rx Az: -32/-36 deg; Tx/Rx El: 0/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>83</index><event>2024-10-14 06:10:55.399, 1471,SYSTEM, LOCAL,  RADIO,   669601 link up; Local/Remote Sector: 1/1; Tx/Rx Beam: 46/46; Tx/Rx Az: -36/-36 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>84</index><event>2024-10-14 06:14:16.503, 1472,SYSTEM, LOCAL,  RADIO,   498371 link up; Local/Remote Sector: 1/1; Tx/Rx Beam: 66/30; Tx/Rx Az: 24/28 deg; Tx/Rx El: 0/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>85</index><event>2024-10-14 06:19:29.539, 1473,SYSTEM, LOCAL,  RADIO,   gnode-g link up; Local/Remote Sector: 1/4; Tx/Rx Beam: 60/60; Tx/Rx Az: 0/0 deg; Tx/Rx El: 0/0 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>86</index><event>2024-10-14 06:20:49.613, 1474,SYSTEM, LOCAL,  RADIO,   488251 link up; Local/Remote Sector: 1/1; Tx/Rx Beam: 56/56; Tx/Rx Az: -16/-16 deg; Tx/Rx El: 0/0 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>87</index><event>2024-10-14 07:41:11.362, 1475,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:01:34:47); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>88</index><event>2024-10-14 07:41:21.238, 1476,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/30; Tx/Rx Az: 20/28 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>89</index><event>2024-10-14 08:29:36.394, 1477,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:48:15); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>9</index><event>2024-10-14 00:23:13.415, 1397,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:16:18); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>90</index><event>2024-10-14 08:29:46.482, 1478,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>91</index><event>2024-10-14 09:30:11.032, 1479,SYSTEM, LOCAL,  RADIO,   570871 link down (was up for 00005:18:55:52); Cause: HeartbeatLossDetected; Local/Remote Sector: 2/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>92</index><event>2024-10-14 09:31:52.646, 1480,SYSTEM, LOCAL,  RADIO,   570871 link up; Local/Remote Sector: 2/1; Tx/Rx Beam: 36/36; Tx/Rx Az: 4/4 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>93</index><event>2024-10-14 11:08:04.590, 1481,SYSTEM, LOCAL,  RADIO,   586111 link down (was up for 00001:22:39:00); Cause: HeartbeatLossDetected; Local/Remote Sector: 2/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>94</index><event>2024-10-14 11:24:52.542, 1482,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:02:55:06); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>95</index><event>2024-10-14 11:25:10.350, 1483,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>96</index><event>2024-10-14 11:25:41.872, 1484,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:00:31); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>97</index><event>2024-10-14 11:25:51.469, 1485,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>98</index><event>2024-10-14 12:24:52.020, 1486,SYSTEM, LOCAL,  RADIO,   498381 link down (was up for 00000:00:59:00); Cause: HeartbeatLossDetected; Local/Remote Sector: 3/1</event></events><events xmlns="http://siklu.com/yang/tg/events"><index>99</index><event>2024-10-14 12:25:03.636, 1487,SYSTEM, LOCAL,  RADIO,   498381 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event></events></rpc-reply>'
    xml = ''' <rpc-reply xmlns="urn:ietf:params:xml:ns:netconf:base:1.0"
                         xmlns:nc="urn:ietf:params:xml:ns:netconf:base:1.0"
                         message-id="urn:uuid:fb6a10dc-1097-4e6d-8cb7-7524fc94d327">
	               <events xmlns="http://siklu.com/yang/tg/events">
		                 <index>0</index>
		                 <event>2024-10-13 23:31:03.784, 1388,SYSTEM, LOCAL,  RADIO,   cn1 link up; Local/Remote Sector: 3/1; Tx/Rx Beam: 32/32; Tx/Rx Az: 20/20 deg; Tx/Rx El: -10/-10 deg</event>
  	               </events>
	              <events xmlns="http://siklu.com/yang/tg/events">
		                 <index>1</index>
		                 <event>2024-10-13 23:56:02.304, 1389,SYSTEM, LOCAL,  RADIO,   cn2 link down (was up for 00000:00:24:58); Cause: LinkNegotiationFailed; Local/Remote Sector: 3/1</event>
	                     </events>
              </rpc-reply>
          '''

    prefix_dict = dict(
        route='192.168.0.1',
        sampled='2024-10-23 17:09:00'
    )
    events = Events.from_xml(xml, prefix_dict)
    print(events)

    # events.append_csv(Path('try.csv'))
    # events.append_csv(Path('try.csv'))
