""" A parser for the output of a MultiHaul TG 'show' """

import ipaddress
from lxml import etree
import re

from tgtools.consts import RE_SW_VER
from tgtools.utils.errlog import Err
from tgtools.utils.miscfuncs import add_commas_thousands, prettyprint_etree


def _concat_sectors(bitmap: int) -> str:
    """
    Convert a 4-bit bit map 'bitmap' to a contatenated string of corresponding sector numbers.
    E.g.: bitmap = 5 = 0b0101 -> '13' (sectors 1 and 3)
    """
    assert 0 < bitmap < 16
    sectors: str = ""
    for sector in ('1', '2', '3', '4'):
        if bitmap & 1:
            sectors += sector
        bitmap >>= 1
    return sectors


class TgParser:
    """ A parser for the XML response of the 'get' RPC (or any valid XML part thereof).
        The XML string is converted to an `lxml.etree <https://lxml.de/tutorial.html>`_, which is then parsed
        by the following high-level sections: *interfaces*, *inventory*, *ipv4*,
        *common_node*, *common_sectors*, *common_links*, *dn_node*, *dn_sectors*, *dn_links*,
        *system*, *user_bridge*.

        Each high-level section is tokenised into a list of dictionaries, where the keys of each
        dictionary comprise some fixed prefix data_tokens, and the more informative data_tokens (specific
        for each section). The values corresponding to each key (token) is derived from the input XML.
        The list for each section is pointed-to by the mapping :attr:`TgParser.parsed`.
        The data_tokens (keys for each dictionary) are pointed to by the mapping :attr:`TgParser.data_tokens`. For example:

         * `TgParser.parsed['interfaces']` is a list of dictionaries, each describing one of the individual
           interface under this section, using certain data_tokens and their respective values.
         * `TgParser.data_tokens['interfaces']` is a list of these data_tokens.

        Some high-level sections are combined to offer a more concise view:
         * *radio-dn/node* and *radio-common/node* are combined in section **node**,
         * *radio-dn/sectors* and *radio-common/sectors* are combined in section **sectors**,
         * *radio-dn/links* and *radio-common/links* are combined in section **links**.
    """

    def __init__(self, xml: str, prefix_tokens: dict[str, str] = None):
        """

        :param xml: an XML string to be parsed.
        :type xml: str
        :param prefix_tokens: an optional dictionary with fixed data_tokens that are prefixed for all
            output dictionaries. Typical keys are 'route' (denoting how a radio was accessed),
            and 'timestamp' (the time at which the XML was obtained from the radio).
        :type prefix_tokens: dict[str, str]
        """

        #: The XML input (argument specified when instantiating this class).
        self.xml: str = xml
        if prefix_tokens:
            self._base_dict = prefix_tokens.copy()
        else:
            self._base_dict = {}
        #: A list of error messages, each represented as :class:`tg.utils.errlog.Err`.
        self.errors: list[Err] = []

        # Convert XML string to etree
        #: The `lxml.etree <https://lxml.de/tutorial.html>`_ representation of :attr:`xml`
        self.xml_etree: etree.Element
        try:
            self.xml_etree = etree.fromstring(xml.encode('utf-8'))
        except etree.LxmlSyntaxError as e:
            error = Err(f"{self.__class__.__qualname__}()",f"lxml.etree: {e}\n{xml}")
            self.errors.append(error)
            self.xml_etree = etree.fromstring('<None/>')
        # The high-level sections on the basis of which :attr:`xml` is parsed.
        self.sections = [
            'interfaces',
            'inventory',
            'ipv4',
            '_common_node',
            '_common_sectors',
            '_common_links',
            '_dn_node',
            '_dn_sectors',
            '_dn_links',
            'system',
            'user_bridge',
            'node',
            'sectors',
            'links',
        ]

        #: The main output of this class: a mapping from each section name to a list of dictionaries,
        #: where each dictionary comprises some data_tokens.
        self.parsed: dict[str, list] = {section: [] for section in self.sections}
        #: A mapping from each section name to a list of its respective data_tokens.
        self.tokens: dict[str, list] = {section: [] for section in self.sections}
        self.tokenise()
        #: The name of the radio (as derived from the *system* section)
        self.local: str
        if len(self.parsed['system']) > 0:
            self.local = self.parsed['system'][0].get('name', '')
        else:
            self.local = ''
        #: A list of all connected remote CNs (as derived from the *radio-dn/links* section).
        self.remote_cns: list[str] = [link['remote'] for link in self.parsed['_dn_links']
                                      if link['type'] == 'cn' and link['state'] == 'Connected']
        #: Post-processing


    def __repr__(self):
        N = 20  # max number of chars to print out in first argument (xml)
        if len(self.xml) > N:
            trunc_get_xml = self.xml[:N] + '...'
        else:
            trunc_get_xml = self.xml
        return f"{self.__class__.__name__}('{trunc_get_xml}', {self._base_dict})"

    def __str__(self):
        string = f"{self.__class__.__name__}:\n"
        string += f"\tLocal name: {self.local}\n"
        string += f"\tRemote CNs: {self.remote_cns}\n"
        for section in self.sections:
            string += f"\tParsed {section}:\n"
            for record in self.parsed[section]:
                string += f"\t\t{record}\n"
        string += f"\tErrors:\n"
        for error in self.errors:
            string += f"\t\t{error}\n"
        return string

    def tokenise(self):
        """ Executes all the different *tokenise_...* methods corresponding to each high-level section.
            Then use :meth:`TgParser.combine_tokens` to combine some sections together for a more comprehensive view.
        """
        _ = self.tokenise_interfaces()
        _ = self.tokenise_inventory()
        _ = self.tokenise_ipv4()
        _ = self.tokenise_common_node()
        _ = self.tokenise_common_sectors()
        _ = self.tokenise_common_links()
        _ = self.tokenise_dn_node()
        _ = self.tokenise_dn_sectors()
        _ = self.tokenise_dn_links()
        _ = self.tokenise_user_bridge()
        _ = self.tokenise_system()
        _ = self.combine_tokens('node', '_dn_node', '_common_node')
        _ = self.combine_tokens('sectors', '_dn_sectors', '_common_sectors', token='sector')
        _ = self.combine_tokens('links', '_dn_links', '_common_links', token='remote')
        return None

    def tokenise_interfaces(self) -> list[dict]:
        """ Tokenise the **interface** section of the input XML.

        Updates :attr:`TgParser.parsed` and :attr:`TgParser.data_tokens`.

        :return: List of dictionaries, each representing (in data_tokens) elements of this section.
        :rtype: list[dict]
        """
        section = 'interfaces'
        root = self.xml_etree.find('.//{*}interfaces')
        tokens = dict(
            ifDescr='{*}ifDescr',
            iftype='{*}iftype',
            ifMtu='{*}ifMtu',
            ifSpeed='{*}ifSpeed',
            mac_address='{*}mac-address',
            admin_status='{*}admin-status',
            oper_status='{*}oper-status',
            auto_negotiation='{*}copper-specific-config/{*}auto-negotiate',
            pse_out='{*}copper-specific-config/{*}pse-out',
            physical_connector_type='{*}physical-connector-type',
            port_speed='{*}port-speed',
            actual_duplex_mode='{*}actual-duplex-mode',
            actual_port_speed='{*}actual-port-speed',
            interface_type='{*}interface-type',
            name='{*}name',
            in_octets='{*}in-octets',
            in_pkts='{*}in-pkts',
            in_discards='{*}in-discards',
            in_errors='{*}in-errors',
            in_no_rule_discards='{*}in-no-rule-discards',
            out_octets='{*}out-octets',
            out_pkts='{*}out-pkts',
            out_discards='{*}out-discards',
            ifLinkUpDownTrapEnable='{*}ifLinkUpDownTrapEnable',
            out_errors='{*}out-errors',
            ifHighSpeed='{*}ifHighSpeed',
            ifPromiscuousMode='{*}ifPromiscuousMode',
            ifConnectorPresent='{*}ifConnectorPresent',
            alias='{*}alias',
            ifCounterDiscontinuityTime='{*}ifCounterDiscontinuityTime',
        )
        record: dict = self._base_dict.copy()
        record.update({key: '' for key in tokens.keys()})
        records: list[dict] = []
        if root is not None:
            for element in root.iterfind('{*}interface'):
                record = self._base_dict.copy()
                record.update({key: element.findtext(value, default='') for key, value in tokens.items()})
                for key in ['ifSpeed', 'in_octets', 'in_pkts', 'in_discards', 'in_errors', 'in_no_rule_discards',
                            'out_octets', 'out_pkts', 'out_discards']:
                    record[key] = add_commas_thousands(record[key])
                records.append(record)
        self.parsed[section] = records
        self.tokens[section] = list(record.keys())
        return self.parsed[section]

    def tokenise_inventory(self) -> list[dict]:
        """ Tokenise the **inventory** section of the input XML.

        Updates :attr:`TgParser.parsed` and :attr:`TgParser.data_tokens`.

        :return: List of dictionaries, each representing (in data_tokens) elements of this section.
        :rtype: list[dict]
        """
        section = 'inventory'
        root = self.xml_etree.find('.//{*}inventory')
        tokens = dict(
            name='{*}name',
            description='{*}description',
            hardware_rev='{*}hardware-rev',
            firmware_rev='{*}firmware-rev',
            software_rev='{*}software-rev',
            serial_num='{*}serial-num',
            mfg_name='{*}mfg-name',
            model_name='{*}model-name',
        )
        record: dict = self._base_dict.copy()
        record.update({key: '' for key in tokens.keys()})
        records: list[dict] = []
        if root is not None:
            for element in root.iterfind('{*}component'):
                fru = element.findtext('{*}is-fru', default='')
                if fru == 'false':
                    continue
                record = self._base_dict.copy()
                record.update({key: element.findtext(value, default='') for key, value in tokens.items()})
                records.append(record)
        self.parsed[section] = records
        self.tokens[section] = list(record.keys())
        return self.parsed[section]

    def tokenise_ipv4(self) -> list[dict]:
        """ Tokenise the **ip/ipv4** section of the input XML.

        Updates :attr:`TgParser.parsed` and :attr:`TgParser.data_tokens`.

        :return: List of dictionaries, each representing (in data_tokens) elements of this section.
        :rtype: list[dict]
        """
        section = 'ipv4'
        root = self.xml_etree.find('.//{*}ipv4')
        tokens = dict(
            ip_addr='{*}ip',
            prefix_len='{*}prefix-length',
            c_vlan='{*}c-vlan',
            default_gateway='{*}default-gateway',
        )
        record: dict = self._base_dict.copy()
        record.update({key: '' for key in tokens.keys()})
        records: list[dict] = []
        if root is not None:
            for element in root.iterfind('{*}address'):
                record = self._base_dict.copy()
                record.update({key: element.findtext(value, default='') for key, value in tokens.items()})
                records.append(record)
            gateway = root.findtext('{*}default-gateway')
            if gateway:
                gateway_ip = ipaddress.IPv4Address(gateway)
                for record in records:
                    network = ipaddress.IPv4Network(f"{record['ip_addr']}/{record['prefix_len']}", strict=False)
                    if gateway_ip in network:
                        record['default_gateway'] = gateway
                        break
        self.parsed[section] = records
        self.tokens[section] = list(record.keys())
        return self.parsed[section]

    def tokenise_common_node(self) -> list[dict]:
        """ Tokenise the **radio_common/node-config** section of the input XML.

        Updates :attr:`TgParser.parsed` and :attr:`TgParser.data_tokens`.

        :return: List of dictionaries, each representing (in data_tokens) elements of this section.
        :rtype: list[dict]
        """
        section = '_common_node'
        root = self.xml_etree.find('.//{*}radio-common/{*}node-config')
        tokens = dict(
            ssid='{*}default-ssid-profile/{*}ssid',
            password='{*}default-ssid-profile/{*}password',
            op_mode='{*}operation-mode',
            dist='{*}link-distance',
            tx_power='{*}tx-power-control',
            dn_link_monitor='{*}dn-link-monitor-timeout',
        )
        record: dict = self._base_dict.copy()
        record.update({key: '' for key in tokens.keys()})
        records: list[dict] = []
        if root is not None:
            record = self._base_dict.copy()
            record.update({key: root.findtext(value, default='') for key, value in tokens.items()})
            records.append(record)
        self.parsed[section] = records
        self.tokens[section] = list(record.keys())
        return self.parsed[section]

    def tokenise_common_sectors(self) -> list[dict]:
        """ Tokenise the **radio_common/sectors-config** section of the input XML.

        Updates :attr:`TgParser.parsed` and :attr:`TgParser.data_tokens`.

        :return: List of dictionaries, each representing (in data_tokens) elements of this section.
        :rtype: list[dict]
        """

        section = '_common_sectors'
        root = self.xml_etree.find('.//{*}radio-common/{*}sectors-config')
        tokens = dict(
            sector='{*}index',
            admin_status='{*}admin-status',
            dn_link_monitor='{*}dn-link-monitor/{*}enabled',
            act_freq='{*}state/{*}frequency',
            antenna='{*}state/{*}antenna-mode',
            sync_mode='{*}state/{*}sync-mode',
            temp_modem='{*}state/{*}temperatures/{*}modem-temperature',
            rf1_temp='place_keeper',
            rf2_temp='place_keeper',
        )
        record: dict = self._base_dict.copy()
        record.update({key: '' for key in tokens.keys()})
        records: list[dict] = []
        if root is not None:
            for element in root.iterfind('{*}sector'):
                record = self._base_dict.copy()
                record.update({key: element.findtext(value, default='') for key, value in tokens.items()})
                for rf in root.iterfind('.//{*}rf'):
                    index = rf.findtext('{*}index')
                    temp = rf.findtext('{*}rf-temperature')
                    if index == '1':
                        record['rf1_temp'] = temp
                    else:
                        record['rf2_temp'] = temp
                records.append(record)
        self.parsed[section] = records
        self.tokens[section] = list(record.keys())
        return self.parsed[section]

    def tokenise_common_links(self) -> list[dict]:
        """ Tokenise the **radio_common/links** section of the input XML.

        Updates :attr:`TgParser.parsed` and :attr:`TgParser.data_tokens`.

        :return: List of dictionaries, each representing (in data_tokens) elements of this section.
        :rtype: list[dict]
        """
        section = '_common_links'
        root = self.xml_etree.find('.//{*}radio-common/{*}links')
        tokens = dict(
            remote='{*}remote-assigned-name',
            role='{*}local-role',
            uptime_link='{*}link-uptime-string',
            uptime_local='place_keeper',
            uptime_remote='place_keeper',
            act_lsec='{*}actual-local-sector-index',
            act_rsec='{*}actual-remote-sector-index',
            tx_power_index='{*}tx-power-index',
            rssi='{*}rssi',
            snr='{*}snr',
            mcs_tx='{*}mcs-tx',
            mcs_rx='{*}mcs-rx',
            tx_per='{*}tx-per',
            rx_per='{*}rx-per',
            antenna='place_keeper',
            tiles_tx='{*}active-tile-count-tx',
            tiles_rx='{*}active-tile-count-rx',
            bm_ind_tx='{*}beam-index-tx',
            bm_az_tx='{*}beam-azimuth-tx',
            bm_el_tx='{*}beam-elevation-tx',
            bm_ind_rx='{*}beam-index-rx',
            bm_az_rx='{*}beam-azimuth-rx',
            bm_el_rx='{*}beam-elevation-rx',
            tx_ok='{*}tx-ok',
            tx_fail='{*}tx-fail',
            tx_exp='{*}tx-failures',
            rx_ok='{*}rx-ok',
            rx_fail='{*}rx-fail',
            rx_hcs='{*}rx-hcs-fail',
            rx_expire='{*}rx-failures',
            rx_buf='{*}rx-drop-buf-size',
            rx_enc='{*}rx-drop-encryption-fail',
            rx_ra_mis='{*}rx-drop-ra-mismatch',
            rx_other='{*}rx-drop-unexpected',
        )
        record: dict = self._base_dict.copy()
        record.update({key: '' for key in tokens.keys()})
        records: list[dict] = []
        if root is not None:
            for element in root.iterfind('{*}active'):
                record = self._base_dict.copy()
                record.update({key: element.findtext(value, default='') for key, value in tokens.items()})
                # truncate role to 4 chars
                record['role'] = record['role'][0:min(4, len(record['role']))]
                # add comma separators for potentially long numbers
                for key in ['tx_ok', 'tx_fail', 'tx_exp',
                            'rx_ok', 'rx_fail', 'rx_hcs', 'rx_expire', 'rx_buf', 'rx_enc', 'rx_ra_mis', 'rx_other']:
                    record[key] = add_commas_thousands(record[key])
                records.append(record)
        self.parsed[section] = records
        self.tokens[section] = list(record.keys())
        return self.parsed[section]

    def tokenise_dn_node(self) -> list[dict]:
        """ Tokenise the **radio_dn/node-config** section of the input XML.

        Updates :attr:`TgParser.parsed` and :attr:`TgParser.data_tokens`.

        :return: List of dictionaries, each representing (in data_tokens) elements of this section.
        :rtype: list[dict]
        """
        section = '_dn_node'
        root = self.xml_etree.find('.//{*}radio-dn/{*}node-config')
        tokens = dict(
            product='place_keeper',
            freq='{*}default-radio-profile/{*}frequency',
            polarity='{*}default-radio-profile/{*}polarity',
            tx_golay='{*}default-radio-profile/{*}tx-golay-index',
            rx_golay='{*}default-radio-profile/{*}rx-golay-index',
            pop_dn='{*}is-pop-dn',
            sync_mode='{*}sync-mode',
        )
        record: dict = self._base_dict.copy()
        record.update({key: '' for key in tokens.keys()})
        records: list[dict] = []
        if root is not None:
            record = self._base_dict.copy()
            record.update({key: root.findtext(value, default='') for key, value in tokens.items()})
            for key in ['freq', 'polarity', 'tx_golay', 'rx_golay']:
                if record[key] == 'unspecified':
                    record[key] = 'unspec'
            records.append(record)
        self.parsed[section] = records
        self.tokens[section] = list(record.keys())
        return self.parsed[section]

    def tokenise_dn_sectors(self) -> list[dict]:
        """ Tokenise the **radio_dn/sectors-config** section of the input XML.

        Updates :attr:`TgParser.parsed` and :attr:`TgParser.data_tokens`.

        :return: List of dictionaries, each representing (in data_tokens) elements of this section.
        :rtype: list[dict]
        """

        section = '_dn_sectors'
        root = self.xml_etree.find('.//{*}radio-dn/{*}sectors-config')
        tokens = dict(
            product='place_keeper',
            sector='{*}index',
            cfg_freq='{*}radio-profile/{*}frequency',
            polarity='{*}radio-profile/{*}polarity',
            tx_golay='{*}radio-profile/{*}tx-golay-index',
            rx_golay='{*}radio-profile/{*}rx-golay-index',
        )
        record: dict = self._base_dict.copy()
        record.update({key: '' for key in tokens.keys()})
        records: list[dict] = []
        if root is not None:
            for element in root.iterfind('{*}sector'):
                record = self._base_dict.copy()
                record.update({key: element.findtext(value, default='') for key, value in tokens.items()})
                for key in ['cfg_freq', 'polarity', 'tx_golay', 'rx_golay']:
                    if record[key] == 'unspecified':
                        record[key] = 'unspec'
                records.append(record)
        self.parsed[section] = records
        self.tokens[section] = list(record.keys())
        return self.parsed[section]

    def tokenise_dn_links(self) -> list[dict]:
        """ Tokenise the **radio_dn/links/configured** section of the input XML.

        Updates :attr:`TgParser.parsed` and :attr:`TgParser.data_tokens`.

        :return: List of dictionaries, each representing (in data_tokens) elements of this section.
        :rtype: list[dict]
        """
        section = '_dn_links'
        root = self.xml_etree.find('.//{*}radio-dn/{*}links')
        tokens = dict(
            remote='{*}remote-assigned-name',
            cfg_lsec='place_keeper',
            cfg_rsec='place_keeper',
            type='{*}responder-node-type',
            admin='{*}admin-status',
            state='{*}dn-link-state',
            tx_golay='{*}tx-golay-index',
            rx_golay='{*}rx-golay-index',
            down_cause='.//{*}down-cause',
        )
        record: dict = self._base_dict.copy()
        record.update({key: '' for key in tokens.keys()})
        records: list[dict] = []
        if root is not None:
            for element in root.iterfind('{*}configured'):
                record = self._base_dict.copy()
                record.update({key: element.findtext(value, default='') for key, value in tokens.items()})
                # If responder-node-type is dn, add control-superframe
                if record['type'] == 'dn':
                    superframe = element.findtext('{*}control-superframe')
                    record['type'] = f"dn{superframe}"
                # Concatenate sectors
                sector_bitmap = int(element.findtext('{*}local-sector-bitmap'))
                if sector_bitmap == 0:
                    sector_bitmap = 1
                record['cfg_lsec'] = _concat_sectors(sector_bitmap)
                sector_bitmap = int(element.findtext('{*}remote-sector-bitmap'))
                if sector_bitmap == 0:
                    sector_bitmap = 1
                record['cfg_rsec'] = _concat_sectors(sector_bitmap)
                # Shorten 'unspecified' to 'unspec'
                for token in ['tx_golay', 'rx_golay']:
                    if record[token] == 'unspecified':
                        record[token] = 'unspec'
                records.append(record)
        self.parsed[section] = records
        self.tokens[section] = list(record.keys())
        return self.parsed[section]

    def tokenise_system(self) -> list[dict]:
        """ Tokenise the **system** section of the input XML.

        Updates :attr:`TgParser.parsed` and :attr:`TgParser.data_tokens`.

        :return: List of dictionaries, each representing (in data_tokens) elements of this section.
        :rtype: list[dict]
        """
        section = 'system'
        root = self.xml_etree.find(f'.//{{*}}{section}')
        tokens = dict(
            name='{*}name',
            product='{*}state/{*}product',
            tod='{*}state/{*}date-and-time',
            uptime='{*}state/{*}uptime',
            sw_active='place_keeper',
            sw_passive='place_keeper',
            gps_fix_mode='{*}state/{*}gps/{*}fix-mode',
            gps_nsats='{*}state/{*}gps/{*}fix-satellites-number',
            contact='{*}contact',
            loc='{*}location',
            gps_lat='{*}state/{*}gps/{*}latitude',
            gps_long='{*}state/{*}gps/{*}longitude',
            gps_height='{*}state/{*}gps/{*}height-sea-level',
            gps_time='{*}state/{*}gps/{*}time',
        )
        record: dict = self._base_dict.copy()
        record.update({key: '' for key in tokens.keys()})
        records: list[dict] = []
        if root is not None:
            record = self._base_dict.copy()
            record.update({key: root.findtext(value, default='') for key, value in tokens.items()})
            for bank in root.iterfind('.//{*}banks'):
                status = bank.findtext('{*}status', default='')
                if m := re.match(RE_SW_VER, bank.findtext('{*}software-version', default='')):
                    sw_version = m[1]
                else:
                    sw_version = 'unknown'
                match status:
                    case 'active':
                        record['sw_active'] = sw_version
                    case 'passive':
                        record['sw_passive'] = sw_version
                    case _:
                        pass
            records.append(record)
        self.parsed[section] = records
        self.tokens[section] = list(record.keys())
        return self.parsed[section]

    def tokenise_user_bridge(self) -> list[dict]:
        """ Tokenise the **radio_common/links** section of the input XML.

        Updates :attr:`TgParser.parsed` and :attr:`TgParser.data_tokens`.

        :return: List of dictionaries, each representing (in data_tokens) elements of this section.
        :rtype: list[dict]
        """
        section = 'user_bridge'
        root = self.xml_etree.find('.//{*}user-bridge')
        tokens1 = dict(
            bridge_id='{*}bridge-id',
        )
        tokens2 = dict(
            port_id='{*}bridge-port-id',
            interface='{*}interface',
            type='{*}bridge-port-type',
            cvlan='{*}c-vlan',
            svlan='{*}s-vlan',
        )

        record: dict = self._base_dict.copy()
        record.update({key: '' for key in tokens1.keys()})
        record.update({key: '' for key in tokens2.keys()})
        records: list[dict] = []
        if root is not None:
            for element in root.iterfind('{*}bridge'):
                record = self._base_dict.copy()
                record.update({key: element.findtext(value, default='') for key, value in tokens1.items()})

                for port in element.iterfind('{*}bridge-port'):
                    bridge_port = record.copy()
                    bridge_port.update({key: port.findtext(value, default='') for key, value in tokens2.items()})
                    if bridge_port['type'] == 'transparent':
                        bridge_port['type'] = 'transp'
                    records.append(bridge_port)
        self.parsed[section] = records
        self.tokens[section] = list(record.keys())
        return self.parsed[section]

    def combine_tokens(self, section_out: str, section_in1: str, section_in2: str, token: str = '') -> list[dict]:
        """ Combines data_tokens of two different sections. If `token` is provided, then elements from
        the two sections are matched based on the value of that token.
        Otherwise, matching is in order (i-th element in `section_in1` combined with i-th element in `section_in2`).

        :param section_out: Name of the new output (combined) section.
        :type section_out: str
        :param section_in1: Name of the first section (of the two) to combine.
        :type section_out: str
        :param section_in2: Name of the second section (of the two) to combine.
        :type section_out: str
        :param token: an optional token for pair-matching elements from `section_in1` and `section_in2`.
        :type section_out: str
        :return: List of dictionaries, each dictionary includes data_tokens combined from both `section_in1` and `section_in2`.
        :rtype: list[dict]
        """
        assert section_in1 in self.sections
        assert section_in2 in self.sections
        list1 = self.parsed[section_in1]
        list2 = self.parsed[section_in2]
        combined_keys = self.tokens[section_in1] + self.tokens[section_in2]
        record_template = dict.fromkeys(combined_keys, '')
        records = []
        processed = []
        if token:
            for item1 in list1:
                record = record_template.copy()
                record.update(item1)
                processed.append(item1[token])
                for item2 in list2:
                    if item2[token] == item1[token]:
                        record.update(item2)
                        break
                records.append(record)
            # Deal with remainders in list2 (those not already processed)
            for item2 in list2:
                if item2[token] not in processed:
                    record = record_template.copy()
                    record.update(item2)
                    records.append(record)
        else:
            for i in range(min(len(list1), len(list2))):
                record = record_template.copy()
                record.update(list1[i])
                record.update(list2[i])
                records.append(record)
            # Save results
        self.parsed[section_out] = records
        self.tokens[section_out] = list(record_template.keys())
        return self.parsed[section_out]



if __name__ == '__main__':
    get_xml = '<rpc-reply xmlns="urn:ietf:params:xml:ns:netconf:base:1.0" xmlns:nc="urn:ietf:params:xml:ns:netconf:base:1.0" message-id="urn:uuid:485abcd2-5642-4c50-a2d0-d20425c6e4c0"><data><snmp xmlns="urn:ietf:params:xml:ns:yang:ietf-snmp"><community><index>ro_entry</index><text-name>public</text-name><security-name>rocommunity</security-name></community><community><index>rw_entry</index><text-name>private</text-name><security-name>rwcommunity</security-name></community></snmp><yang-library xmlns="urn:ietf:params:xml:ns:yang:ietf-yang-library"><module-set><name>default</name><module><name>IANAifType-MIB</name><revision>2016-06-16</revision><namespace>urn:ietf:params:xml:ns:yang:smiv2:IANAifType-MIB</namespace></module><module><name>SNMPv2-TC</name><namespace>urn:ietf:params:xml:ns:yang:smiv2:SNMPv2-TC</namespace></module><module><name>clixon-autocli</name><revision>2021-12-05</revision><namespace>http://clicon.org/autocli</namespace></module><module><name>clixon-lib</name><revision>2022-12-01</revision><namespace>http://clicon.org/lib</namespace></module><module><name>clixon-snmp</name><revision>2023-01-17</revision><namespace>http://clicon.org/snmp</namespace></module><module><name>ieee802-dot1q-cfm</name><revision>2020-06-04</revision><namespace>urn:ieee:std:802.1Q:yang:ieee802-dot1q-cfm</namespace></module><module><name>ieee802-dot1q-cfm-types</name><revision>2020-06-04</revision><namespace>urn:ieee:std:802.1Q:yang:ieee802-dot1q-cfm-types</namespace></module><module><name>ieee802-dot1q-types</name><revision>2020-06-04</revision><namespace>urn:ieee:std:802.1Q:yang:ieee802-dot1q-types</namespace></module><module><name>ieee802-types</name><revision>2020-06-04</revision><namespace>urn:ieee:std:802.1Q:yang:ieee802-types</namespace></module><module><name>ietf-datastores</name><revision>2018-02-14</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-datastores</namespace></module><module><name>ietf-inet-types</name><revision>2013-07-15</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-inet-types</namespace></module><module><name>ietf-list-pagination</name><revision>2022-07-24</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-list-pagination</namespace></module><module><name>ietf-list-pagination-nc</name><revision>2022-07-24</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-list-pagination-nc</namespace></module><module><name>ietf-netconf</name><revision>2011-06-01</revision><namespace>urn:ietf:params:xml:ns:netconf:base:1.0</namespace><feature>candidate</feature><feature>startup</feature><feature>validate</feature><feature>xpath</feature></module><module><name>ietf-netconf-acm</name><revision>2018-02-14</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-netconf-acm</namespace></module><module><name>ietf-netconf-monitoring</name><revision>2010-10-04</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring</namespace></module><module><name>ietf-netconf-nmda</name><revision>2019-01-07</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-netconf-nmda</namespace></module><module><name>ietf-netconf-with-defaults</name><revision>2011-06-01</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults</namespace></module><module><name>ietf-origin</name><revision>2018-02-14</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-origin</namespace></module><module><name>ietf-restconf</name><revision>2017-01-26</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-restconf</namespace></module><module><name>ietf-snmp</name><revision>2014-12-10</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-snmp</namespace><submodule><name>ietf-snmp-common</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-community</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-engine</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-notification</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-proxy</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-ssh</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-target</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-tls</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-tsm</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-usm</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-vacm</name><revision>2014-12-10</revision></submodule></module><module><name>ietf-x509-cert-to-name</name><revision>2014-12-10</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-x509-cert-to-name</namespace></module><module><name>ietf-yang-library</name><revision>2022-12-12</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-yang-library</namespace></module><module><name>ietf-yang-metadata</name><revision>2016-08-05</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-yang-metadata</namespace></module><module><name>ietf-yang-smiv2</name><revision>2012-06-22</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-yang-smiv2</namespace></module><module><name>ietf-yang-types</name><revision>2013-07-15</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-yang-types</namespace></module><module><name>radio-bridge-tg-acm</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/acm</namespace></module><module><name>radio-bridge-tg-bond</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/bond</namespace></module><module><name>radio-bridge-tg-cfm</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/cfm</namespace></module><module><name>radio-bridge-tg-database-version</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/database-version</namespace></module><module><name>radio-bridge-tg-events</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/events</namespace></module><module><name>radio-bridge-tg-gps</name><revision>2024-05-27</revision><namespace>http://siklu.com/yang/tg/gps</namespace></module><module><name>radio-bridge-tg-gui</name><revision>2023-05-16</revision><namespace>http://siklu.com/yang/tg/gui</namespace></module><module><name>radio-bridge-tg-interfaces</name><revision>2023-05-16</revision><namespace>http://siklu.com/yang/tg/interfaces</namespace></module><module><name>radio-bridge-tg-inventory</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/inventory</namespace></module><module><name>radio-bridge-tg-ip</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/ip</namespace></module><module><name>radio-bridge-tg-logging</name><revision>2024-02-16</revision><namespace>http://siklu.com/yang/tg/logging</namespace></module><module><name>radio-bridge-tg-ping</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/ping</namespace></module><module><name>radio-bridge-tg-pm</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/pm</namespace></module><module><name>radio-bridge-tg-radio-common</name><revision>2024-01-16</revision><namespace>http://siklu.com/yang/tg/radio</namespace></module><module><name>radio-bridge-tg-radio-dn</name><revision>2024-04-03</revision><namespace>http://siklu.com/yang/tg/radio/dn</namespace></module><module><name>radio-bridge-tg-rollback</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/rollback</namespace></module><module><name>radio-bridge-tg-snmp</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/snmp</namespace></module><module><name>radio-bridge-tg-software-upgrade</name><revision>2023-06-05</revision><namespace>http://siklu.com/yang/tg/software-upgrade</namespace></module><module><name>radio-bridge-tg-spider-attenuation-control</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/spider/attenuation</namespace></module><module><name>radio-bridge-tg-system</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/system</namespace></module><module><name>radio-bridge-tg-tunnel</name><revision>2022-07-26</revision><namespace>http://siklu.com/yang/tg/tunnel</namespace></module><module><name>radio-bridge-tg-types</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/types</namespace></module><module><name>radio-bridge-tg-user-bridge</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/user-bridge</namespace></module><module><name>radio-bridge-tg-user-management</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/user-management</namespace></module></module-set><content-id>0</content-id></yang-library><database-version xmlns="http://siklu.com/yang/tg/database-version"><database-version-number>43</database-version-number></database-version><gui xmlns="http://siklu.com/yang/tg/gui"><icon xmlns="http://siklu.com/yang/tg/gui">cTU</icon></gui><if-number xmlns="http://siklu.com/yang/tg/interfaces"><ifNumber xmlns="http://siklu.com/yang/tg/interfaces">3</ifNumber></if-number><interfaces xmlns="http://siklu.com/yang/tg/interfaces"><interface><ifIndex>101</ifIndex><ifDescr>eth1 RJ-45 1Gbps</ifDescr><iftype>ethernetCsmacd</iftype><ifMtu>1500</ifMtu><ifSpeed>1000000000</ifSpeed><admin-status>up</admin-status><oper-status>up</oper-status><ifInOctets>24457361</ifInOctets><ifInUcastPkts>183552</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>647247565</ifOutOctets><ifOutUcastPkts>24087669</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><copper-specific-config><auto-negotiate>true</auto-negotiate></copper-specific-config><physical-connector-type>RJ-45</physical-connector-type><port-speed>1Gbps</port-speed><actual-duplex-mode>full</actual-duplex-mode><actual-port-speed>1Gbps</actual-port-speed><interface-type>ethernet</interface-type><name>eth1</name><in-octets>24457361</in-octets><in-pkts>183552</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>31</in-no-rule-discards><out-octets>13532149453</out-octets><out-pkts>24087669</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifLinkUpDownTrapEnable>disabled</ifLinkUpDownTrapEnable><ifHighSpeed>1000</ifHighSpeed><ifPromiscuousMode>false</ifPromiscuousMode><ifConnectorPresent>true</ifConnectorPresent><alias/><ifCounterDiscontinuityTime>0</ifCounterDiscontinuityTime></interface><interface><ifIndex>102</ifIndex><ifDescr>Host CPU interface</ifDescr><iftype>other</iftype><ifMtu>1500</ifMtu><ifSpeed>0</ifSpeed><mac-address>00:24:a4:1c:f9:71</mac-address><oper-status>up</oper-status><ifInOctets>1114</ifInOctets><ifInUcastPkts>13</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>641929103</ifOutOctets><ifOutUcastPkts>24001188</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>host</interface-type><name>host</name><in-octets>1114</in-octets><in-pkts>13</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>4</in-no-rule-discards><out-octets>13526830991</out-octets><out-pkts>24001188</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifLinkUpDownTrapEnable>disabled</ifLinkUpDownTrapEnable><ifHighSpeed>0</ifHighSpeed><ifPromiscuousMode>false</ifPromiscuousMode><ifConnectorPresent>false</ifConnectorPresent><ifCounterDiscontinuityTime>0</ifCounterDiscontinuityTime></interface><interface><ifIndex>103</ifIndex><ifDescr>rf-gnode-a</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>1272767434</ifInOctets><ifInUcastPkts>31108575</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>636714579</ifOutOctets><ifOutUcastPkts>6961319</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-gnode-a</name><in-octets>14157669322</in-octets><in-pkts>31108575</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>1853</in-no-rule-discards><out-octets>636714579</out-octets><out-pkts>6961319</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface></interfaces><inventory xmlns="http://siklu.com/yang/tg/inventory"><component><name>MH-T260</name><index>1</index><description>MH-T260</description><vendor-type>0.0</vendor-type><parent-index>0</parent-index><physical-class>chassis</physical-class><parent-rel-pos>-1</parent-rel-pos><child><name>Baseband</name></child><child><name>RF sector 1</name></child><hardware-rev>A2</hardware-rev><firmware-rev/><software-rev>2.3.1-3781-145719c14</software-rev><serial-num>FD08659404</serial-num><mfg-name>Siklu</mfg-name><model-name>MH-T260-CNN-N-MWB</model-name><is-fru>true</is-fru></component><component><name>Baseband</name><index>2</index><description>Baseband</description><vendor-type>0.0</vendor-type><parent>MH-T260</parent><parent-index>1</parent-index><physical-class>cpu</physical-class><parent-rel-pos>0</parent-rel-pos><child><name>Bootloader</name></child><child><name>eth1</name></child><hardware-rev>A0.0</hardware-rev><firmware-rev/><software-rev/><serial-num>FD01650017</serial-num><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>RF sector 1</name><index>3</index><description>RF sector 1</description><vendor-type>0.0</vendor-type><parent>MH-T260</parent><parent-index>1</parent-index><physical-class>other</physical-class><parent-rel-pos>1</parent-rel-pos><child><name>RF sector 1 Antenna</name></child><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>Bootloader</name><index>4</index><description>Bootloader</description><vendor-type>0.0</vendor-type><parent>Baseband</parent><parent-index>2</parent-index><physical-class>other</physical-class><parent-rel-pos>0</parent-rel-pos><hardware-rev/><firmware-rev>1.0.0-883-c697e1a38a</firmware-rev><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>eth1</name><index>5</index><description>RJ-45,1G/100M Ethernet port</description><vendor-type>0.0</vendor-type><parent>Baseband</parent><parent-index>2</parent-index><physical-class>port</physical-class><parent-rel-pos>1</parent-rel-pos><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>RF sector 1 Antenna</name><index>6</index><description>Integrated Beam Forming 90deg</description><vendor-type>0.0</vendor-type><parent>RF sector 1</parent><parent-index>3</parent-index><physical-class>other</physical-class><parent-rel-pos>0</parent-rel-pos><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component></inventory><ip xmlns="http://siklu.com/yang/tg/ip"><ipv4><address><ip>192.168.0.1</ip><prefix-length>24</prefix-length></address></ipv4><ipv6><link-local>fe80::2:6aff:fe26:8f80</link-local></ipv6></ip><radio-common xmlns="http://siklu.com/yang/tg/radio"><node-config><default-ssid-profile><ssid>MultiHaul</ssid><password>MultiHaul</password></default-ssid-profile><operation-mode>TU</operation-mode><link-distance>Long</link-distance><available-operation-mode><operation-mode>TU</operation-mode></available-operation-mode><tx-power-control>auto</tx-power-control><dn-link-monitor-timeout>600</dn-link-monitor-timeout></node-config><sectors-config><sector><index>1</index><admin-status>up</admin-status><dn-link-monitor><enabled>false</enabled></dn-link-monitor><state><mac-addr>02:02:6a:26:8f:80</mac-addr><frequency>58320</frequency><antenna-mode>massive2</antenna-mode><sync-mode>rf</sync-mode><temperatures><modem-temperature>30</modem-temperature><rf><index>1</index><rf-temperature>23</rf-temperature></rf><rf><index>2</index><rf-temperature>23</rf-temperature></rf></temperatures></state></sector></sectors-config><links><active><ifIndex>103</ifIndex><remote-assigned-name>gnode-a</remote-assigned-name><actual-remote-sector-index>4</actual-remote-sector-index><actual-local-sector-index>1</actual-local-sector-index><remote-mac-addr>02:06:7b:2d:37:93</remote-mac-addr><local-role>responder</local-role><link-uptime-ticks>27600</link-uptime-ticks><link-uptime>747041</link-uptime><link-uptime-string>00008:15:30:41</link-uptime-string><rssi>-58</rssi><snr>15.0</snr><mcs-rx>12</mcs-rx><mcs-tx>12</mcs-tx><tx-per>10.0</tx-per><rx-per>49.0</rx-per><tx-power-index>21</tx-power-index><speed-rx>3800</speed-rx><speed-tx>3800</speed-tx><beam-index-rx>72</beam-index-rx><beam-azimuth-rx>9</beam-azimuth-rx><beam-elevation-rx>0</beam-elevation-rx><active-tile-count-rx>2</active-tile-count-rx><beam-index-tx>72</beam-index-tx><beam-azimuth-tx>9</beam-azimuth-tx><beam-elevation-tx>0</beam-elevation-tx><active-tile-count-tx>2</active-tile-count-tx><rx-ok>25740342</rx-ok><tx-ok>6938475</tx-ok><tx-fail>1598738</tx-fail><rx-fail>4676328</rx-fail><rx-hcs-fail>350731</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>5027061</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>2</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active></links></radio-common><radio-dn xmlns="http://siklu.com/yang/tg/radio/dn"><node-config><default-radio-profile><frequency>unspecified</frequency><polarity>unspecified</polarity><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></default-radio-profile><sync-mode>no-sync</sync-mode><sync-state><is-locked>false</is-locked></sync-state><rf-sync><enabled>true</enabled><allow-free-running>false</allow-free-running></rf-sync></node-config><ignition-config><idle-timer>600</idle-timer><ignition-timer>240</ignition-timer><retry-count>2</retry-count></ignition-config></radio-dn><system xmlns="http://siklu.com/yang/tg/system"><name>679011</name><contact/><reboot-needed xmlns="http://siklu.com/yang/tg/system">false</reboot-needed><location/><control><soft-watchdog-enabled>true</soft-watchdog-enabled></control><state><snmp-object-id>1.3.6.1.4.1.31926.35</snmp-object-id><snmp-services>2</snmp-services><product>MH-T260</product><date-and-time>2024-10-23 06:18:33</date-and-time><uptime>00008:15:35:17</uptime><uptime-hundredths-seconds>74731700</uptime-hundredths-seconds><is-rollback-active>true</is-rollback-active><banks-info><banks><number>0</number><software-version>2.1.1-3215-af9ea50ff</software-version><status>passive</status><scheduled-to-switch>idle</scheduled-to-switch></banks><banks><number>1</number><software-version>2.3.1-3781-145719c14</software-version><status>active</status><scheduled-to-switch>idle</scheduled-to-switch></banks></banks-info><sw-upgrade-info><download-and-burning-state>not-started</download-and-burning-state></sw-upgrade-info><technician-file-creation>idle</technician-file-creation></state></system><user-bridge xmlns="http://siklu.com/yang/tg/user-bridge"><bridge><bridge-id>1</bridge-id><bridge-port><bridge-port-id>1</bridge-port-id><interface>eth1</interface><bridge-port-type>transparent</bridge-port-type></bridge-port><bridge-port><bridge-port-id>2</bridge-port-id><interface>host</interface><bridge-port-type>transparent</bridge-port-type></bridge-port><bridge-port><bridge-port-id>3</bridge-port-id><interface>rf</interface><bridge-port-type>transparent</bridge-port-type></bridge-port></bridge><bridge><bridge-id>2</bridge-id><bridge-port><bridge-port-id>1</bridge-port-id><interface>eth1</interface><bridge-port-type>c-vlan</bridge-port-type><c-vlan>579</c-vlan></bridge-port><bridge-port><bridge-port-id>2</bridge-port-id><interface>eth1</interface><bridge-port-type>s-vlan</bridge-port-type><s-vlan>445</s-vlan></bridge-port></bridge></user-bridge><user-management xmlns="http://siklu.com/yang/tg/user-management"><user><username>admin</username><password>$5$4xwj7jmV/eFTMdXe$u/Jk73dGQcz.u4Xu.6LxMKqeKRRG2Z/R17kRTpJSqg.</password></user></user-management></data></rpc-reply>'
    #get_xml = '<rpc-reply xmlns="urn:ietf:params:xml:ns:netconf:base:1.0" xmlns:nc="urn:ietf:params:xml:ns:netconf:base:1.0" message-id="urn:uuid:523bc7f3-b9ba-4f3a-a0c4-57766066e40d"><data><snmp xmlns="urn:ietf:params:xml:ns:yang:ietf-snmp"><community><index>ro_entry</index><text-name>public</text-name><security-name>rocommunity</security-name></community><community><index>rw_entry</index><text-name>private</text-name><security-name>rwcommunity</security-name></community></snmp><yang-library xmlns="urn:ietf:params:xml:ns:yang:ietf-yang-library"><module-set><name>default</name><module><name>IANAifType-MIB</name><revision>2016-06-16</revision><namespace>urn:ietf:params:xml:ns:yang:smiv2:IANAifType-MIB</namespace></module><module><name>SNMPv2-TC</name><namespace>urn:ietf:params:xml:ns:yang:smiv2:SNMPv2-TC</namespace></module><module><name>clixon-autocli</name><revision>2021-12-05</revision><namespace>http://clicon.org/autocli</namespace></module><module><name>clixon-lib</name><revision>2022-12-01</revision><namespace>http://clicon.org/lib</namespace></module><module><name>clixon-snmp</name><revision>2023-01-17</revision><namespace>http://clicon.org/snmp</namespace></module><module><name>ieee802-dot1q-cfm</name><revision>2020-06-04</revision><namespace>urn:ieee:std:802.1Q:yang:ieee802-dot1q-cfm</namespace></module><module><name>ieee802-dot1q-cfm-types</name><revision>2020-06-04</revision><namespace>urn:ieee:std:802.1Q:yang:ieee802-dot1q-cfm-types</namespace></module><module><name>ieee802-dot1q-types</name><revision>2020-06-04</revision><namespace>urn:ieee:std:802.1Q:yang:ieee802-dot1q-types</namespace></module><module><name>ieee802-types</name><revision>2020-06-04</revision><namespace>urn:ieee:std:802.1Q:yang:ieee802-types</namespace></module><module><name>ietf-datastores</name><revision>2018-02-14</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-datastores</namespace></module><module><name>ietf-inet-types</name><revision>2013-07-15</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-inet-types</namespace></module><module><name>ietf-list-pagination</name><revision>2022-07-24</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-list-pagination</namespace></module><module><name>ietf-list-pagination-nc</name><revision>2022-07-24</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-list-pagination-nc</namespace></module><module><name>ietf-netconf</name><revision>2011-06-01</revision><namespace>urn:ietf:params:xml:ns:netconf:base:1.0</namespace><feature>candidate</feature><feature>startup</feature><feature>validate</feature><feature>xpath</feature></module><module><name>ietf-netconf-acm</name><revision>2018-02-14</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-netconf-acm</namespace></module><module><name>ietf-netconf-monitoring</name><revision>2010-10-04</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-netconf-monitoring</namespace></module><module><name>ietf-netconf-nmda</name><revision>2019-01-07</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-netconf-nmda</namespace></module><module><name>ietf-netconf-with-defaults</name><revision>2011-06-01</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-netconf-with-defaults</namespace></module><module><name>ietf-origin</name><revision>2018-02-14</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-origin</namespace></module><module><name>ietf-restconf</name><revision>2017-01-26</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-restconf</namespace></module><module><name>ietf-snmp</name><revision>2014-12-10</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-snmp</namespace><submodule><name>ietf-snmp-common</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-community</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-engine</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-notification</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-proxy</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-ssh</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-target</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-tls</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-tsm</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-usm</name><revision>2014-12-10</revision></submodule><submodule><name>ietf-snmp-vacm</name><revision>2014-12-10</revision></submodule></module><module><name>ietf-x509-cert-to-name</name><revision>2014-12-10</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-x509-cert-to-name</namespace></module><module><name>ietf-yang-library</name><revision>2022-12-12</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-yang-library</namespace></module><module><name>ietf-yang-metadata</name><revision>2016-08-05</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-yang-metadata</namespace></module><module><name>ietf-yang-smiv2</name><revision>2012-06-22</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-yang-smiv2</namespace></module><module><name>ietf-yang-types</name><revision>2013-07-15</revision><namespace>urn:ietf:params:xml:ns:yang:ietf-yang-types</namespace></module><module><name>radio-bridge-tg-acm</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/acm</namespace></module><module><name>radio-bridge-tg-bond</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/bond</namespace></module><module><name>radio-bridge-tg-cfm</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/cfm</namespace></module><module><name>radio-bridge-tg-database-version</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/database-version</namespace></module><module><name>radio-bridge-tg-events</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/events</namespace></module><module><name>radio-bridge-tg-gps</name><revision>2024-05-27</revision><namespace>http://siklu.com/yang/tg/gps</namespace></module><module><name>radio-bridge-tg-gui</name><revision>2023-05-16</revision><namespace>http://siklu.com/yang/tg/gui</namespace></module><module><name>radio-bridge-tg-interfaces</name><revision>2023-05-16</revision><namespace>http://siklu.com/yang/tg/interfaces</namespace></module><module><name>radio-bridge-tg-inventory</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/inventory</namespace></module><module><name>radio-bridge-tg-ip</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/ip</namespace></module><module><name>radio-bridge-tg-logging</name><revision>2024-02-16</revision><namespace>http://siklu.com/yang/tg/logging</namespace></module><module><name>radio-bridge-tg-ping</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/ping</namespace></module><module><name>radio-bridge-tg-pm</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/pm</namespace></module><module><name>radio-bridge-tg-radio-common</name><revision>2024-01-16</revision><namespace>http://siklu.com/yang/tg/radio</namespace></module><module><name>radio-bridge-tg-radio-dn</name><revision>2024-04-03</revision><namespace>http://siklu.com/yang/tg/radio/dn</namespace></module><module><name>radio-bridge-tg-rollback</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/rollback</namespace></module><module><name>radio-bridge-tg-snmp</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/snmp</namespace></module><module><name>radio-bridge-tg-software-upgrade</name><revision>2023-06-05</revision><namespace>http://siklu.com/yang/tg/software-upgrade</namespace></module><module><name>radio-bridge-tg-spider-attenuation-control</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/spider/attenuation</namespace></module><module><name>radio-bridge-tg-system</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/system</namespace></module><module><name>radio-bridge-tg-tunnel</name><revision>2022-07-26</revision><namespace>http://siklu.com/yang/tg/tunnel</namespace></module><module><name>radio-bridge-tg-types</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/types</namespace><feature>sync-mode-gps</feature><feature>sync-mode-rf</feature></module><module><name>radio-bridge-tg-user-bridge</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/user-bridge</namespace></module><module><name>radio-bridge-tg-user-management</name><revision>2023-04-20</revision><namespace>http://siklu.com/yang/tg/user-management</namespace></module></module-set><content-id>0</content-id></yang-library><database-version xmlns="http://siklu.com/yang/tg/database-version"><database-version-number>43</database-version-number></database-version><gui xmlns="http://siklu.com/yang/tg/gui"><icon xmlns="http://siklu.com/yang/tg/gui">Node</icon></gui><if-number xmlns="http://siklu.com/yang/tg/interfaces"><ifNumber xmlns="http://siklu.com/yang/tg/interfaces">34</ifNumber></if-number><interfaces xmlns="http://siklu.com/yang/tg/interfaces"><interface><ifIndex>103</ifIndex><ifDescr>eth1 RJ-45 10Gbps</ifDescr><iftype>ethernetCsmacd</iftype><ifMtu>1500</ifMtu><ifSpeed>4294967295</ifSpeed><admin-status>up</admin-status><oper-status>up</oper-status><ifInOctets>3238253949</ifInOctets><ifInUcastPkts>1593688447</ifInUcastPkts><ifInDiscards>118</ifInDiscards><ifInErrors>474</ifInErrors><ifOutOctets>2572874227</ifOutOctets><ifOutUcastPkts>693971331</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><copper-specific-config><auto-negotiate>true</auto-negotiate></copper-specific-config><physical-connector-type>RJ-45</physical-connector-type><port-speed>10Gbps</port-speed><actual-duplex-mode>full</actual-duplex-mode><actual-port-speed>1Gbps</actual-port-speed><interface-type>ethernet</interface-type><name>eth1</name><in-octets>1991808111997</in-octets><in-pkts>1593688447</in-pkts><in-discards>118</in-discards><in-errors>474</in-errors><in-no-rule-discards>301</in-no-rule-discards><out-octets>144306794995</out-octets><out-pkts>693971331</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifLinkUpDownTrapEnable>disabled</ifLinkUpDownTrapEnable><ifHighSpeed>10000</ifHighSpeed><ifPromiscuousMode>false</ifPromiscuousMode><ifConnectorPresent>true</ifConnectorPresent><alias/><ifCounterDiscontinuityTime>0</ifCounterDiscontinuityTime></interface><interface><ifIndex>101</ifIndex><ifDescr>eth2 RJ-45 1Gbps</ifDescr><iftype>ethernetCsmacd</iftype><ifMtu>1500</ifMtu><ifSpeed>1000000000</ifSpeed><admin-status>down</admin-status><oper-status>down</oper-status><ifInOctets>0</ifInOctets><ifInUcastPkts>0</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>0</ifOutOctets><ifOutUcastPkts>0</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><copper-specific-config><auto-negotiate>true</auto-negotiate><pse-out>true</pse-out></copper-specific-config><physical-connector-type>RJ-45</physical-connector-type><port-speed>1Gbps</port-speed><interface-type>ethernet</interface-type><name>eth2</name><in-octets>0</in-octets><in-pkts>0</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>0</in-no-rule-discards><out-octets>0</out-octets><out-pkts>0</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifLinkUpDownTrapEnable>disabled</ifLinkUpDownTrapEnable><ifHighSpeed>1000</ifHighSpeed><ifPromiscuousMode>false</ifPromiscuousMode><ifConnectorPresent>true</ifConnectorPresent><alias/><ifCounterDiscontinuityTime>0</ifCounterDiscontinuityTime></interface><interface><ifIndex>102</ifIndex><ifDescr>eth3 SFP+ 10Gbps</ifDescr><iftype>ethernetCsmacd</iftype><ifMtu>1500</ifMtu><ifSpeed>4294967295</ifSpeed><admin-status>down</admin-status><oper-status>down</oper-status><ifInOctets>0</ifInOctets><ifInUcastPkts>0</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>0</ifOutOctets><ifOutUcastPkts>0</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><copper-specific-config><auto-negotiate>true</auto-negotiate></copper-specific-config><physical-connector-type>SFP+</physical-connector-type><port-speed>10Gbps</port-speed><interface-type>ethernet</interface-type><name>eth3</name><in-octets>0</in-octets><in-pkts>0</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>0</in-no-rule-discards><out-octets>0</out-octets><out-pkts>0</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifLinkUpDownTrapEnable>disabled</ifLinkUpDownTrapEnable><ifHighSpeed>10000</ifHighSpeed><ifPromiscuousMode>false</ifPromiscuousMode><ifConnectorPresent>true</ifConnectorPresent><alias/><ifCounterDiscontinuityTime>0</ifCounterDiscontinuityTime></interface><interface><ifIndex>104</ifIndex><ifDescr>Host CPU interface</ifDescr><iftype>other</iftype><ifMtu>1500</ifMtu><ifSpeed>0</ifSpeed><mac-address>00:24:a4:19:fb:89</mac-address><oper-status>up</oper-status><ifInOctets>1731253500</ifInOctets><ifInUcastPkts>3527114</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>1324716381</ifOutOctets><ifOutUcastPkts>138390522</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>host</interface-type><name>host</name><in-octets>1731253500</in-octets><in-pkts>3527114</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>4</in-no-rule-discards><out-octets>39979422045</out-octets><out-pkts>138390522</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifLinkUpDownTrapEnable>disabled</ifLinkUpDownTrapEnable><ifHighSpeed>0</ifHighSpeed><ifPromiscuousMode>false</ifPromiscuousMode><ifConnectorPresent>false</ifConnectorPresent><ifCounterDiscontinuityTime>0</ifCounterDiscontinuityTime></interface><interface><ifIndex>105</ifIndex><ifDescr>rf-488251</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>1489503868</ifInOctets><ifInUcastPkts>13079605</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>352744401</ifOutOctets><ifOutUcastPkts>63401272</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-488251</name><in-octets>1489503868</in-octets><in-pkts>13079605</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>1</in-no-rule-discards><out-octets>60482286545</out-octets><out-pkts>63401272</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>106</ifIndex><ifDescr>rf-497691</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>down</oper-status><ifInOctets>0</ifInOctets><ifInUcastPkts>0</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>0</ifOutOctets><ifOutUcastPkts>0</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-497691</name><in-octets>0</in-octets><in-pkts>0</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>0</in-no-rule-discards><out-octets>0</out-octets><out-pkts>0</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>107</ifIndex><ifDescr>rf-498371</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>3529760236</ifInOctets><ifInUcastPkts>28757171</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>3943660931</ifOutOctets><ifOutUcastPkts>75170207</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-498371</name><in-octets>3529760236</in-octets><in-pkts>28757171</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>1</in-no-rule-discards><out-octets>76958104963</out-octets><out-pkts>75170207</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>108</ifIndex><ifDescr>rf-498381</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>1071340923</ifInOctets><ifInUcastPkts>9182489</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>872571418</ifOutOctets><ifOutUcastPkts>27248745</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-498381</name><in-octets>1071340923</in-octets><in-pkts>9182489</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>8</in-no-rule-discards><out-octets>18052440602</out-octets><out-pkts>27248745</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>109</ifIndex><ifDescr>rf-526391</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>down</oper-status><ifInOctets>0</ifInOctets><ifInUcastPkts>0</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>0</ifOutOctets><ifOutUcastPkts>0</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-526391</name><in-octets>0</in-octets><in-pkts>0</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>0</in-no-rule-discards><out-octets>0</out-octets><out-pkts>0</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>110</ifIndex><ifDescr>rf-551141</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>559196593</ifInOctets><ifInUcastPkts>27197277</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>1382114216</ifOutOctets><ifOutUcastPkts>86160924</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-551141</name><in-octets>4854163889</in-octets><in-pkts>27197277</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>1</in-no-rule-discards><out-octets>91576427432</out-octets><out-pkts>86160924</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>111</ifIndex><ifDescr>rf-552191</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>1620470452</ifInOctets><ifInUcastPkts>24802979</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>1053140124</ifOutOctets><ifOutUcastPkts>77301175</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-552191</name><in-octets>5915437748</in-octets><in-pkts>24802979</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>0</in-no-rule-discards><out-octets>74067584156</out-octets><out-pkts>77301175</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>112</ifIndex><ifDescr>rf-553901</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>1512057488</ifInOctets><ifInUcastPkts>12758845</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>1840650084</ifOutOctets><ifOutUcastPkts>41564741</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-553901</name><in-octets>1512057488</in-octets><in-pkts>12758845</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>1</in-no-rule-discards><out-octets>27610453860</out-octets><out-pkts>41564741</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>113</ifIndex><ifDescr>rf-556821</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>1561728342</ifInOctets><ifInUcastPkts>12886566</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>2119048722</ifOutOctets><ifOutUcastPkts>41890561</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-556821</name><in-octets>1561728342</in-octets><in-pkts>12886566</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>1</in-no-rule-discards><out-octets>27888852498</out-octets><out-pkts>41890561</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>114</ifIndex><ifDescr>rf-559611</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>2182911092</ifInOctets><ifInUcastPkts>25325532</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>3831490407</ifOutOctets><ifOutUcastPkts>89457873</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-559611</name><in-octets>6477878388</in-octets><in-pkts>25325532</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>576</in-no-rule-discards><out-octets>94025803623</out-octets><out-pkts>89457873</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>115</ifIndex><ifDescr>rf-567421</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>2647811724</ifInOctets><ifInUcastPkts>14277827</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>3538939034</ifOutOctets><ifOutUcastPkts>69094867</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-567421</name><in-octets>2647811724</in-octets><in-pkts>14277827</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>1</in-no-rule-discards><out-octets>63668481178</out-octets><out-pkts>69094867</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>116</ifIndex><ifDescr>rf-567731</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>1532964399</ifInOctets><ifInUcastPkts>12851419</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>2026807128</ifOutOctets><ifOutUcastPkts>41681900</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-567731</name><in-octets>1532964399</in-octets><in-pkts>12851419</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>2</in-no-rule-discards><out-octets>27796610904</out-octets><out-pkts>41681900</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>117</ifIndex><ifDescr>rf-570871</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>623519519</ifInOctets><ifInUcastPkts>6759867</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>1329838486</ifOutOctets><ifOutUcastPkts>30819388</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-570871</name><in-octets>623519519</in-octets><in-pkts>6759867</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>1</in-no-rule-discards><out-octets>14214740374</out-octets><out-pkts>30819388</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>118</ifIndex><ifDescr>rf-570881</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>1528470474</ifInOctets><ifInUcastPkts>12897039</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>2395633749</ifOutOctets><ifOutUcastPkts>41955796</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-570881</name><in-octets>1528470474</in-octets><in-pkts>12897039</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>2</in-no-rule-discards><out-octets>28165437525</out-octets><out-pkts>41955796</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>119</ifIndex><ifDescr>rf-576641</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>1301441023</ifInOctets><ifInUcastPkts>6492162</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>1597452205</ifOutOctets><ifOutUcastPkts>18533625</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-576641</name><in-octets>1301441023</in-octets><in-pkts>6492162</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>0</in-no-rule-discards><out-octets>23072288685</out-octets><out-pkts>18533625</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>120</ifIndex><ifDescr>rf-577481</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>down</oper-status><interface-type>rf</interface-type><name>rf-577481</name><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>121</ifIndex><ifDescr>rf-579901</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>626200985</ifInOctets><ifInUcastPkts>6816801</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>1284033913</ifOutOctets><ifOutUcastPkts>31065376</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-579901</name><in-octets>626200985</in-octets><in-pkts>6816801</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>1</in-no-rule-discards><out-octets>14168935801</out-octets><out-pkts>31065376</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>122</ifIndex><ifDescr>rf-582691</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>2676206780</ifInOctets><ifInUcastPkts>71717329</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>484335571</ifOutOctets><ifOutUcastPkts>168363255</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-582691</name><in-octets>11266141372</in-octets><in-pkts>71717329</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>0</in-no-rule-discards><out-octets>202347798483</out-octets><out-pkts>168363255</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>123</ifIndex><ifDescr>rf-586111</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>down</oper-status><ifInOctets>0</ifInOctets><ifInUcastPkts>0</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>0</ifOutOctets><ifOutUcastPkts>0</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-586111</name><in-octets>0</in-octets><in-pkts>0</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>0</in-no-rule-discards><out-octets>0</out-octets><out-pkts>0</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>124</ifIndex><ifDescr>rf-588932</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>284540174</ifInOctets><ifInUcastPkts>1026710</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>2542989542</ifOutOctets><ifOutUcastPkts>3033022</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-588932</name><in-octets>284540174</in-octets><in-pkts>1026710</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>0</in-no-rule-discards><out-octets>2542989542</out-octets><out-pkts>3033022</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>125</ifIndex><ifDescr>rf-608651</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>2355938766</ifInOctets><ifInUcastPkts>46845693</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>4099182410</ifOutOctets><ifOutUcastPkts>120035937</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-608651</name><in-octets>6650906062</in-octets><in-pkts>46845693</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>1</in-no-rule-discards><out-octets>137243168586</out-octets><out-pkts>120035937</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>126</ifIndex><ifDescr>rf-611211</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>1514366066</ifInOctets><ifInUcastPkts>13008707</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>2021857296</ifOutOctets><ifOutUcastPkts>41622452</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-611211</name><in-octets>1514366066</in-octets><in-pkts>13008707</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>1</in-no-rule-discards><out-octets>27791661072</out-octets><out-pkts>41622452</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>127</ifIndex><ifDescr>rf-659751</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>down</oper-status><interface-type>rf</interface-type><name>rf-659751</name><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>128</ifIndex><ifDescr>rf-662111</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>642612020</ifInOctets><ifInUcastPkts>6925820</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>1335958655</ifOutOctets><ifOutUcastPkts>31183498</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-662111</name><in-octets>642612020</in-octets><in-pkts>6925820</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>0</in-no-rule-discards><out-octets>14220860543</out-octets><out-pkts>31183498</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>129</ifIndex><ifDescr>rf-669601</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>616732321</ifInOctets><ifInUcastPkts>6857513</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>1282388941</ifOutOctets><ifOutUcastPkts>31101899</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-669601</name><in-octets>616732321</in-octets><in-pkts>6857513</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>1</in-no-rule-discards><out-octets>14167290829</out-octets><out-pkts>31101899</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>130</ifIndex><ifDescr>rf-672611</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>617036636</ifInOctets><ifInUcastPkts>6862994</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>1283007853</ifOutOctets><ifOutUcastPkts>31107544</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-672611</name><in-octets>617036636</in-octets><in-pkts>6862994</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>1</in-no-rule-discards><out-octets>14167909741</out-octets><out-pkts>31107544</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>131</ifIndex><ifDescr>rf-679011</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>637498401</ifInOctets><ifInUcastPkts>6966064</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>1284500626</ifOutOctets><ifOutUcastPkts>31127487</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-679011</name><in-octets>637498401</in-octets><in-pkts>6966064</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>1</in-no-rule-discards><out-octets>14169402514</out-octets><out-pkts>31127487</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>132</ifIndex><ifDescr>rf-701581</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>down</oper-status><interface-type>rf</interface-type><name>rf-701581</name><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>133</ifIndex><ifDescr>rf-gnode-g</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>4230169812</ifInOctets><ifInUcastPkts>251290310</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>2910632002</ifOutOctets><ifOutUcastPkts>609028832</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-gnode-g</name><in-octets>47179842772</in-octets><in-pkts>251290310</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>38</in-no-rule-discards><out-octets>797479581762</out-octets><out-pkts>609028832</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface><interface><ifIndex>134</ifIndex><ifDescr>rf-gpop</ifDescr><iftype>radioMAC</iftype><ifMtu>1500</ifMtu><ifSpeed>3800000000</ifSpeed><oper-status>up</oper-status><ifInOctets>3936314784</ifInOctets><ifInUcastPkts>1092407419</ifInUcastPkts><ifInDiscards>0</ifInDiscards><ifInErrors>0</ifInErrors><ifOutOctets>2975830215</ifOutOctets><ifOutUcastPkts>438487920</ifOutUcastPkts><ifOutDiscards>0</ifOutDiscards><ifOutErrors>0</ifOutErrors><interface-type>rf</interface-type><name>rf-gpop</name><in-octets>1451340293536</in-octets><in-pkts>1092407419</in-pkts><in-discards>0</in-discards><in-errors>0</in-errors><in-no-rule-discards>109</in-no-rule-discards><out-octets>93170143431</out-octets><out-pkts>438487920</out-pkts><out-discards>0</out-discards><out-errors>0</out-errors><ifHighSpeed>3800</ifHighSpeed><ifConnectorPresent>true</ifConnectorPresent></interface></interfaces><inventory xmlns="http://siklu.com/yang/tg/inventory"><component><name>MH-N366</name><index>1</index><description>MH-N366</description><vendor-type>0.0</vendor-type><parent-index>0</parent-index><physical-class>chassis</physical-class><parent-rel-pos>-1</parent-rel-pos><child><name>Baseband</name></child><child><name>Gps</name></child><child><name>RF sector 1</name></child><child><name>RF sector 2</name></child><child><name>RF sector 3</name></child><child><name>RF sector 4</name></child><hardware-rev>A2</hardware-rev><firmware-rev/><software-rev>2.3.0-3778-214041e90</software-rev><serial-num>FB46545416</serial-num><mfg-name>Siklu</mfg-name><model-name>MH-N366-CCP-PoE-MWB</model-name><is-fru>true</is-fru></component><component><name>Baseband</name><index>2</index><description>Baseband</description><vendor-type>0.0</vendor-type><parent>MH-N366</parent><parent-index>1</parent-index><physical-class>cpu</physical-class><parent-rel-pos>0</parent-rel-pos><child><name>Bootloader</name></child><child><name>eth1</name></child><child><name>eth2</name></child><child><name>eth3</name></child><hardware-rev>A1.0</hardware-rev><firmware-rev/><software-rev/><serial-num>FB46545248</serial-num><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>Gps</name><index>3</index><description>GPS module</description><vendor-type>0.0</vendor-type><parent>MH-N366</parent><parent-index>1</parent-index><physical-class>module</physical-class><parent-rel-pos>1</parent-rel-pos><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>RF sector 1</name><index>4</index><description>RF sector 1</description><vendor-type>0.0</vendor-type><parent>MH-N366</parent><parent-index>1</parent-index><physical-class>other</physical-class><parent-rel-pos>2</parent-rel-pos><child><name>RF sector 1 Antenna</name></child><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>RF sector 2</name><index>5</index><description>RF sector 2</description><vendor-type>0.0</vendor-type><parent>MH-N366</parent><parent-index>1</parent-index><physical-class>other</physical-class><parent-rel-pos>3</parent-rel-pos><child><name>RF sector 2 Antenna</name></child><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>RF sector 3</name><index>6</index><description>RF sector 3</description><vendor-type>0.0</vendor-type><parent>MH-N366</parent><parent-index>1</parent-index><physical-class>other</physical-class><parent-rel-pos>4</parent-rel-pos><child><name>RF sector 3 Antenna</name></child><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>RF sector 4</name><index>7</index><description>RF sector 4</description><vendor-type>0.0</vendor-type><parent>MH-N366</parent><parent-index>1</parent-index><physical-class>other</physical-class><parent-rel-pos>5</parent-rel-pos><child><name>RF sector 4 Antenna</name></child><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>Bootloader</name><index>8</index><description>Bootloader</description><vendor-type>0.0</vendor-type><parent>Baseband</parent><parent-index>2</parent-index><physical-class>other</physical-class><parent-rel-pos>0</parent-rel-pos><hardware-rev/><firmware-rev>1.0.0-21903-228ffeaaa0</firmware-rev><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>eth2</name><index>9</index><description>RJ-45,1G/100M Ethernet port</description><vendor-type>0.0</vendor-type><parent>Baseband</parent><parent-index>2</parent-index><physical-class>port</physical-class><parent-rel-pos>1</parent-rel-pos><child><name>eth2_pse</name></child><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>eth3</name><index>10</index><description>SFP+,10G/1G cage</description><vendor-type>0.0</vendor-type><parent>Baseband</parent><parent-index>2</parent-index><physical-class>container</physical-class><parent-rel-pos>2</parent-rel-pos><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>eth1</name><index>11</index><description>RJ-45,10G/5G/2.5G/1G/100M Ethernet port</description><vendor-type>0.0</vendor-type><parent>Baseband</parent><parent-index>2</parent-index><physical-class>port</physical-class><parent-rel-pos>3</parent-rel-pos><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>RF sector 1 Antenna</name><index>12</index><description>Integrated Beam Forming</description><vendor-type>0.0</vendor-type><parent>RF sector 1</parent><parent-index>4</parent-index><physical-class>other</physical-class><parent-rel-pos>0</parent-rel-pos><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>RF sector 2 Antenna</name><index>13</index><description>Integrated Beam Forming</description><vendor-type>0.0</vendor-type><parent>RF sector 2</parent><parent-index>5</parent-index><physical-class>other</physical-class><parent-rel-pos>0</parent-rel-pos><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>RF sector 3 Antenna</name><index>14</index><description>Integrated Beam Forming</description><vendor-type>0.0</vendor-type><parent>RF sector 3</parent><parent-index>6</parent-index><physical-class>other</physical-class><parent-rel-pos>0</parent-rel-pos><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>RF sector 4 Antenna</name><index>15</index><description>Integrated Beam Forming</description><vendor-type>0.0</vendor-type><parent>RF sector 4</parent><parent-index>7</parent-index><physical-class>other</physical-class><parent-rel-pos>0</parent-rel-pos><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component><component><name>eth2_pse</name><index>16</index><description>PoE Power Sourcing Equipment (PSE) for eth2 port</description><vendor-type>0.0</vendor-type><parent>eth2</parent><parent-index>9</parent-index><physical-class>other</physical-class><parent-rel-pos>0</parent-rel-pos><hardware-rev/><firmware-rev/><software-rev/><serial-num/><mfg-name/><model-name/><is-fru>false</is-fru></component></inventory><ip xmlns="http://siklu.com/yang/tg/ip"><ipv4><address><ip>172.19.40.10</ip><prefix-length>24</prefix-length><c-vlan>20</c-vlan></address><address><ip>192.168.0.100</ip><prefix-length>24</prefix-length></address><default-gateway>172.19.40.1</default-gateway></ipv4><ipv6><link-local>fe80::6:7bff:fe2d:3790</link-local></ipv6></ip><radio-common xmlns="http://siklu.com/yang/tg/radio"><node-config><default-ssid-profile><ssid>MultiHaul</ssid><password>MultiHaul</password></default-ssid-profile><operation-mode>BU</operation-mode><link-distance>Long</link-distance><available-operation-mode><operation-mode>BU</operation-mode></available-operation-mode><tx-power-control>auto</tx-power-control><dn-link-monitor-timeout>600</dn-link-monitor-timeout></node-config><sectors-config><sector><index>1</index><admin-status>up</admin-status><dn-link-monitor><enabled>false</enabled></dn-link-monitor><state><mac-addr>02:06:7b:2d:37:90</mac-addr><frequency>60480</frequency><antenna-mode>normal</antenna-mode><sync-mode>internal</sync-mode><temperatures><modem-temperature>43</modem-temperature><rf><index>1</index><rf-temperature>52</rf-temperature></rf></temperatures></state></sector><sector><index>2</index><admin-status>up</admin-status><dn-link-monitor><enabled>false</enabled></dn-link-monitor><state><mac-addr>02:06:7b:2d:37:91</mac-addr><frequency>58320</frequency><antenna-mode>normal</antenna-mode><sync-mode>internal</sync-mode><temperatures><modem-temperature>50</modem-temperature><rf><index>1</index><rf-temperature>65</rf-temperature></rf></temperatures></state></sector><sector><index>3</index><admin-status>up</admin-status><dn-link-monitor><enabled>false</enabled></dn-link-monitor><state><mac-addr>02:06:7b:2d:37:92</mac-addr><frequency>60480</frequency><antenna-mode>normal</antenna-mode><sync-mode>internal</sync-mode><temperatures><modem-temperature>36</modem-temperature><rf><index>1</index><rf-temperature>52</rf-temperature></rf></temperatures></state></sector><sector><index>4</index><admin-status>up</admin-status><dn-link-monitor><enabled>false</enabled></dn-link-monitor><state><mac-addr>02:06:7b:2d:37:93</mac-addr><frequency>58320</frequency><antenna-mode>normal</antenna-mode><sync-mode>internal</sync-mode><temperatures><modem-temperature>36</modem-temperature><rf><index>1</index><rf-temperature>45</rf-temperature></rf></temperatures></state></sector></sectors-config><links><active><ifIndex>105</ifIndex><remote-assigned-name>488251</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>1</actual-local-sector-index><remote-mac-addr>02:02:6c:62:84:18</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72382000</link-uptime-ticks><link-uptime>746513</link-uptime><link-uptime-string>00008:15:21:53</link-uptime-string><rssi>-51</rssi><snr>22.0</snr><mcs-rx>9</mcs-rx><mcs-tx>12</mcs-tx><tx-per>0.0</tx-per><rx-per>0.0</rx-per><tx-power-index>21</tx-power-index><speed-rx>2050</speed-rx><speed-tx>3800</speed-tx><beam-index-rx>55</beam-index-rx><beam-azimuth-rx>-20</beam-azimuth-rx><beam-elevation-rx>0</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>55</beam-index-tx><beam-azimuth-tx>-20</beam-azimuth-tx><beam-elevation-tx>0</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>10582750</rx-ok><tx-ok>38870475</tx-ok><tx-fail>3432065</tx-fail><rx-fail>506021</rx-fail><rx-hcs-fail>1063922</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>1569943</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>0</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>107</ifIndex><remote-assigned-name>498371</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>1</actual-local-sector-index><remote-mac-addr>02:02:6d:80:8a:98</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72342700</link-uptime-ticks><link-uptime>746907</link-uptime><link-uptime-string>00008:15:28:27</link-uptime-string><rssi>-62</rssi><snr>12.0</snr><mcs-rx>12</mcs-rx><mcs-tx>11</mcs-tx><tx-per>0.0</tx-per><rx-per>0.0</rx-per><tx-power-index>14</tx-power-index><speed-rx>3800</speed-rx><speed-tx>3150</speed-tx><beam-index-rx>31</beam-index-rx><beam-azimuth-rx>24</beam-azimuth-rx><beam-elevation-rx>-10</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>66</beam-index-tx><beam-azimuth-tx>24</beam-azimuth-tx><beam-elevation-tx>0</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>19146597</rx-ok><tx-ok>44888744</tx-ok><tx-fail>3186825</tx-fail><rx-fail>1134681</rx-fail><rx-hcs-fail>142511</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>1277194</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>2</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>108</ifIndex><remote-assigned-name>498381</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>3</actual-local-sector-index><remote-mac-addr>02:02:6e:0d:be:1c</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>95087200</link-uptime-ticks><link-uptime>519462</link-uptime><link-uptime-string>00006:00:17:42</link-uptime-string><rssi>-64</rssi><snr>9.0</snr><mcs-rx>6</mcs-rx><mcs-tx>2</mcs-tx><tx-per>26.3</tx-per><rx-per>0.0</rx-per><tx-power-index>31</tx-power-index><speed-rx>1260</speed-rx><speed-tx>620</speed-tx><beam-index-rx>31</beam-index-rx><beam-azimuth-rx>24</beam-azimuth-rx><beam-elevation-rx>-10</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>31</beam-index-tx><beam-azimuth-tx>24</beam-azimuth-tx><beam-elevation-tx>-10</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>7853065</rx-ok><tx-ok>19502272</tx-ok><tx-fail>6081981</tx-fail><rx-fail>474383</rx-fail><rx-hcs-fail>399326</rx-hcs-fail><tx-failures>10</tx-failures><rx-failures>873709</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>0</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>110</ifIndex><remote-assigned-name>551141</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>4</actual-local-sector-index><remote-mac-addr>02:02:6b:d1:09:8c</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72269400</link-uptime-ticks><link-uptime>747640</link-uptime><link-uptime-string>00008:15:40:40</link-uptime-string><rssi>-59</rssi><snr>14.0</snr><mcs-rx>12</mcs-rx><mcs-tx>12</mcs-tx><tx-per>3.9</tx-per><rx-per>13.0</rx-per><tx-power-index>22</tx-power-index><speed-rx>3800</speed-rx><speed-tx>3800</speed-tx><beam-index-rx>40</beam-index-rx><beam-azimuth-rx>-12</beam-azimuth-rx><beam-elevation-rx>-10</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>40</beam-index-tx><beam-azimuth-tx>-12</beam-azimuth-tx><beam-elevation-tx>-10</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>19236284</rx-ok><tx-ok>53377210</tx-ok><tx-fail>3612648</tx-fail><rx-fail>3672861</rx-fail><rx-hcs-fail>421</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>3673283</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>1</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>111</ifIndex><remote-assigned-name>552191</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>1</actual-local-sector-index><remote-mac-addr>02:02:6e:93:22:e4</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72270400</link-uptime-ticks><link-uptime>747630</link-uptime><link-uptime-string>00008:15:40:30</link-uptime-string><rssi>-59</rssi><snr>15.0</snr><mcs-rx>12</mcs-rx><mcs-tx>12</mcs-tx><tx-per>0.0</tx-per><rx-per>0.0</rx-per><tx-power-index>13</tx-power-index><speed-rx>3800</speed-rx><speed-tx>3800</speed-tx><beam-index-rx>20</beam-index-rx><beam-azimuth-rx>24</beam-azimuth-rx><beam-elevation-rx>-20</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>20</beam-index-tx><beam-azimuth-tx>24</beam-azimuth-tx><beam-elevation-tx>-20</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>17101074</rx-ok><tx-ok>46439348</tx-ok><tx-fail>3816698</tx-fail><rx-fail>1585419</rx-fail><rx-hcs-fail>130026</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>1715449</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>4</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>112</ifIndex><remote-assigned-name>553901</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>1</actual-local-sector-index><remote-mac-addr>02:02:69:b9:61:e4</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72298900</link-uptime-ticks><link-uptime>747345</link-uptime><link-uptime-string>00008:15:35:45</link-uptime-string><rssi>-65</rssi><snr>8.0</snr><mcs-rx>9</mcs-rx><mcs-tx>9</mcs-tx><tx-per>0.0</tx-per><rx-per>0.0</rx-per><tx-power-index>24</tx-power-index><speed-rx>2050</speed-rx><speed-tx>2050</speed-tx><beam-index-rx>46</beam-index-rx><beam-azimuth-rx>-36</beam-azimuth-rx><beam-elevation-rx>-10</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>46</beam-index-tx><beam-azimuth-tx>-36</beam-azimuth-tx><beam-elevation-tx>-10</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>10615084</rx-ok><tx-ok>27878059</tx-ok><tx-fail>1813364</tx-fail><rx-fail>613573</rx-fail><rx-hcs-fail>484137</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>1097710</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>0</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>113</ifIndex><remote-assigned-name>556821</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>1</actual-local-sector-index><remote-mac-addr>02:02:6a:d0:71:5c</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72300500</link-uptime-ticks><link-uptime>747329</link-uptime><link-uptime-string>00008:15:35:29</link-uptime-string><rssi>-67</rssi><snr>6.0</snr><mcs-rx>9</mcs-rx><mcs-tx>9</mcs-tx><tx-per>0.0</tx-per><rx-per>36.4</rx-per><tx-power-index>27</tx-power-index><speed-rx>2050</speed-rx><speed-tx>2050</speed-tx><beam-index-rx>3</beam-index-rx><beam-azimuth-rx>-44</beam-azimuth-rx><beam-elevation-rx>-20</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>94</beam-index-tx><beam-azimuth-tx>-44</beam-azimuth-tx><beam-elevation-tx>10</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>10567713</rx-ok><tx-ok>28092674</tx-ok><tx-fail>1307148</tx-fail><rx-fail>603244</rx-fail><rx-hcs-fail>204928</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>808173</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>1</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>114</ifIndex><remote-assigned-name>559611</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>3</actual-local-sector-index><remote-mac-addr>02:02:6a:3c:47:6c</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>88267700</link-uptime-ticks><link-uptime>587657</link-uptime><link-uptime-string>00006:19:14:17</link-uptime-string><rssi>-61</rssi><snr>12.0</snr><mcs-rx>12</mcs-rx><mcs-tx>6</mcs-tx><tx-per>0.0</tx-per><rx-per>37.5</rx-per><tx-power-index>30</tx-power-index><speed-rx>3800</speed-rx><speed-tx>1260</speed-tx><beam-index-rx>31</beam-index-rx><beam-azimuth-rx>24</beam-azimuth-rx><beam-elevation-rx>-10</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>66</beam-index-tx><beam-azimuth-tx>24</beam-azimuth-tx><beam-elevation-tx>0</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>19217126</rx-ok><tx-ok>53648087</tx-ok><tx-fail>7299246</tx-fail><rx-fail>2412461</rx-fail><rx-hcs-fail>243943</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>2656414</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>10</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>115</ifIndex><remote-assigned-name>567421</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>2</actual-local-sector-index><remote-mac-addr>02:02:6a:c2:0e:4c</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72274000</link-uptime-ticks><link-uptime>747594</link-uptime><link-uptime-string>00008:15:39:54</link-uptime-string><rssi>-64</rssi><snr>10.0</snr><mcs-rx>9</mcs-rx><mcs-tx>10</mcs-tx><tx-per>7.7</tx-per><rx-per>0.0</rx-per><tx-power-index>24</tx-power-index><speed-rx>2050</speed-rx><speed-tx>2500</speed-tx><beam-index-rx>54</beam-index-rx><beam-azimuth-rx>-24</beam-azimuth-rx><beam-elevation-rx>0</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>54</beam-index-tx><beam-azimuth-tx>-24</beam-azimuth-tx><beam-elevation-tx>0</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>11080228</rx-ok><tx-ok>40862145</tx-ok><tx-fail>1839176</tx-fail><rx-fail>702666</rx-fail><rx-hcs-fail>355</rx-hcs-fail><tx-failures>1</tx-failures><rx-failures>703021</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>0</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>116</ifIndex><remote-assigned-name>567731</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>1</actual-local-sector-index><remote-mac-addr>02:02:6b:5a:1e:64</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72307400</link-uptime-ticks><link-uptime>747260</link-uptime><link-uptime-string>00008:15:34:20</link-uptime-string><rssi>-60</rssi><snr>14.0</snr><mcs-rx>12</mcs-rx><mcs-tx>12</mcs-tx><tx-per>18.8</tx-per><rx-per>0.0</rx-per><tx-power-index>21</tx-power-index><speed-rx>3800</speed-rx><speed-tx>3800</speed-tx><beam-index-rx>52</beam-index-rx><beam-azimuth-rx>-32</beam-azimuth-rx><beam-elevation-rx>0</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>52</beam-index-tx><beam-azimuth-tx>-32</beam-azimuth-tx><beam-elevation-tx>0</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>10451713</rx-ok><tx-ok>27913354</tx-ok><tx-fail>2791853</tx-fail><rx-fail>935415</rx-fail><rx-hcs-fail>675642</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>1611057</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>0</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>117</ifIndex><remote-assigned-name>570871</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>2</actual-local-sector-index><remote-mac-addr>02:02:6d:91:e5:90</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>73528300</link-uptime-ticks><link-uptime>735050</link-uptime><link-uptime-string>00008:12:10:50</link-uptime-string><rssi>-58</rssi><snr>16.0</snr><mcs-rx>12</mcs-rx><mcs-tx>12</mcs-tx><tx-per>6.7</tx-per><rx-per>0.0</rx-per><tx-power-index>17</tx-power-index><speed-rx>3800</speed-rx><speed-tx>3800</speed-tx><beam-index-rx>36</beam-index-rx><beam-azimuth-rx>4</beam-azimuth-rx><beam-elevation-rx>-10</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>36</beam-index-tx><beam-azimuth-tx>4</beam-azimuth-tx><beam-elevation-tx>-10</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>6726742</rx-ok><tx-ok>21995685</tx-ok><tx-fail>2598055</tx-fail><rx-fail>1101208</rx-fail><rx-hcs-fail>1611</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>1102819</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>0</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>118</ifIndex><remote-assigned-name>570881</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>2</actual-local-sector-index><remote-mac-addr>02:02:6e:1f:19:14</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72275800</link-uptime-ticks><link-uptime>747576</link-uptime><link-uptime-string>00008:15:39:36</link-uptime-string><rssi>-57</rssi><snr>16.0</snr><mcs-rx>12</mcs-rx><mcs-tx>11</mcs-tx><tx-per>0.0</tx-per><rx-per>0.0</rx-per><tx-power-index>23</tx-power-index><speed-rx>3800</speed-rx><speed-tx>3150</speed-tx><beam-index-rx>64</beam-index-rx><beam-azimuth-rx>16</beam-azimuth-rx><beam-elevation-rx>0</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>64</beam-index-tx><beam-azimuth-tx>16</beam-azimuth-tx><beam-elevation-tx>0</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>10608125</rx-ok><tx-ok>27143534</tx-ok><tx-fail>2131292</tx-fail><rx-fail>1725657</rx-fail><rx-hcs-fail>4844</rx-hcs-fail><tx-failures>2</tx-failures><rx-failures>1730503</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>2</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>119</ifIndex><remote-assigned-name>576641</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>1</actual-local-sector-index><remote-mac-addr>02:02:6b:e3:9b:e4</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>137945000</link-uptime-ticks><link-uptime>90884</link-uptime><link-uptime-string>00001:01:14:44</link-uptime-string><rssi>-60</rssi><snr>14.0</snr><mcs-rx>12</mcs-rx><mcs-tx>12</mcs-tx><tx-per>0.0</tx-per><rx-per>0.0</rx-per><tx-power-index>7</tx-power-index><speed-rx>3800</speed-rx><speed-tx>3800</speed-tx><beam-index-rx>39</beam-index-rx><beam-azimuth-rx>-8</beam-azimuth-rx><beam-elevation-rx>-10</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>39</beam-index-tx><beam-azimuth-tx>-8</beam-azimuth-tx><beam-elevation-tx>-10</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>4051278</rx-ok><tx-ok>10292451</tx-ok><tx-fail>556479</tx-fail><rx-fail>119503</rx-fail><rx-hcs-fail>78</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>119581</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>0</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>121</ifIndex><remote-assigned-name>579901</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>4</actual-local-sector-index><remote-mac-addr>02:02:69:b9:f1:b4</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72279900</link-uptime-ticks><link-uptime>747535</link-uptime><link-uptime-string>00008:15:38:55</link-uptime-string><rssi>-59</rssi><snr>14.0</snr><mcs-rx>12</mcs-rx><mcs-tx>12</mcs-tx><tx-per>0.0</tx-per><rx-per>52.6</rx-per><tx-power-index>23</tx-power-index><speed-rx>3800</speed-rx><speed-tx>3800</speed-tx><beam-index-rx>45</beam-index-rx><beam-azimuth-rx>-32</beam-azimuth-rx><beam-elevation-rx>-10</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>45</beam-index-tx><beam-azimuth-tx>-32</beam-azimuth-tx><beam-elevation-tx>-10</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>6807646</rx-ok><tx-ok>24057885</tx-ok><tx-fail>2472249</tx-fail><rx-fail>2656752</rx-fail><rx-hcs-fail>284</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>2657036</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>0</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>122</ifIndex><remote-assigned-name>582691</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>2</actual-local-sector-index><remote-mac-addr>02:02:6e:a5:3f:04</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>98524000</link-uptime-ticks><link-uptime>485094</link-uptime><link-uptime-string>00005:14:44:54</link-uptime-string><rssi>-60</rssi><snr>13.0</snr><mcs-rx>11</mcs-rx><mcs-tx>9</mcs-tx><tx-per>0.0</tx-per><rx-per>6.1</rx-per><tx-power-index>23</tx-power-index><speed-rx>3150</speed-rx><speed-tx>2050</speed-tx><beam-index-rx>36</beam-index-rx><beam-azimuth-rx>4</beam-azimuth-rx><beam-elevation-rx>-10</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>36</beam-index-tx><beam-azimuth-tx>4</beam-azimuth-tx><beam-elevation-tx>-10</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>42405680</rx-ok><tx-ok>92199124</tx-ok><tx-fail>3750826</tx-fail><rx-fail>1499556</rx-fail><rx-hcs-fail>61546</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>1561111</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>9</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>124</ifIndex><remote-assigned-name>588932</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>2</actual-local-sector-index><remote-mac-addr>02:02:80:e4:4e:34</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>143212000</link-uptime-ticks><link-uptime>38214</link-uptime><link-uptime-string>00000:10:36:54</link-uptime-string><rssi>-56</rssi><snr>17.0</snr><mcs-rx>12</mcs-rx><mcs-tx>11</mcs-tx><tx-per>0.0</tx-per><rx-per>7.7</rx-per><tx-power-index>19</tx-power-index><speed-rx>3800</speed-rx><speed-tx>3150</speed-tx><beam-index-rx>64</beam-index-rx><beam-azimuth-rx>16</beam-azimuth-rx><beam-elevation-rx>0</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>64</beam-index-tx><beam-azimuth-tx>16</beam-azimuth-tx><beam-elevation-tx>0</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>762486</rx-ok><tx-ok>1914505</tx-ok><tx-fail>192978</tx-fail><rx-fail>79911</rx-fail><rx-hcs-fail>106</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>80017</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>0</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>125</ifIndex><remote-assigned-name>608651</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>2</actual-local-sector-index><remote-mac-addr>02:02:6c:70:fa:b0</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72284400</link-uptime-ticks><link-uptime>747490</link-uptime><link-uptime-string>00008:15:38:10</link-uptime-string><rssi>-59</rssi><snr>14.0</snr><mcs-rx>12</mcs-rx><mcs-tx>11</mcs-tx><tx-per>0.0</tx-per><rx-per>25.0</rx-per><tx-power-index>21</tx-power-index><speed-rx>3800</speed-rx><speed-tx>3150</speed-tx><beam-index-rx>48</beam-index-rx><beam-azimuth-rx>-44</beam-azimuth-rx><beam-elevation-rx>-10</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>48</beam-index-tx><beam-azimuth-tx>-44</beam-azimuth-tx><beam-elevation-tx>-10</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>29768710</rx-ok><tx-ok>68949693</tx-ok><tx-fail>5939136</tx-fail><rx-fail>1851766</rx-fail><rx-hcs-fail>223</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>1851992</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>3</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>126</ifIndex><remote-assigned-name>611211</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>2</actual-local-sector-index><remote-mac-addr>02:02:6a:2d:0b:70</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72286400</link-uptime-ticks><link-uptime>747470</link-uptime><link-uptime-string>00008:15:37:50</link-uptime-string><rssi>-59</rssi><snr>14.0</snr><mcs-rx>12</mcs-rx><mcs-tx>12</mcs-tx><tx-per>0.0</tx-per><rx-per>0.0</rx-per><tx-power-index>16</tx-power-index><speed-rx>3800</speed-rx><speed-tx>3800</speed-tx><beam-index-rx>44</beam-index-rx><beam-azimuth-rx>-28</beam-azimuth-rx><beam-elevation-rx>-10</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>44</beam-index-tx><beam-azimuth-tx>-28</beam-azimuth-tx><beam-elevation-tx>-10</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>10714382</rx-ok><tx-ok>27946289</tx-ok><tx-fail>2464084</tx-fail><rx-fail>1607784</rx-fail><rx-hcs-fail>301</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>1608089</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>4</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>128</ifIndex><remote-assigned-name>662111</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>2</actual-local-sector-index><remote-mac-addr>02:02:6a:29:87:64</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72289000</link-uptime-ticks><link-uptime>747444</link-uptime><link-uptime-string>00008:15:37:24</link-uptime-string><rssi>-57</rssi><snr>16.0</snr><mcs-rx>12</mcs-rx><mcs-tx>9</mcs-tx><tx-per>0.0</tx-per><rx-per>0.0</rx-per><tx-power-index>23</tx-power-index><speed-rx>3800</speed-rx><speed-tx>2050</speed-tx><beam-index-rx>55</beam-index-rx><beam-azimuth-rx>-20</beam-azimuth-rx><beam-elevation-rx>0</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>42</beam-index-tx><beam-azimuth-tx>-20</beam-azimuth-tx><beam-elevation-tx>-10</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>6889987</rx-ok><tx-ok>22366277</tx-ok><tx-fail>1208861</tx-fail><rx-fail>951677</rx-fail><rx-hcs-fail>607</rx-hcs-fail><tx-failures>1</tx-failures><rx-failures>952284</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>0</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>129</ifIndex><remote-assigned-name>669601</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>1</actual-local-sector-index><remote-mac-addr>02:02:69:af:14:88</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72322600</link-uptime-ticks><link-uptime>747108</link-uptime><link-uptime-string>00008:15:31:48</link-uptime-string><rssi>-66</rssi><snr>7.0</snr><mcs-rx>9</mcs-rx><mcs-tx>9</mcs-tx><tx-per>0.0</tx-per><rx-per>0.0</rx-per><tx-power-index>29</tx-power-index><speed-rx>2050</speed-rx><speed-tx>2050</speed-tx><beam-index-rx>46</beam-index-rx><beam-azimuth-rx>-36</beam-azimuth-rx><beam-elevation-rx>-10</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>46</beam-index-tx><beam-azimuth-tx>-36</beam-azimuth-tx><beam-elevation-tx>-10</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>6919457</rx-ok><tx-ok>22262048</tx-ok><tx-fail>1776084</tx-fail><rx-fail>474002</rx-fail><rx-hcs-fail>513264</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>987266</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>0</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>130</ifIndex><remote-assigned-name>672611</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>2</actual-local-sector-index><remote-mac-addr>02:02:6a:3b:a2:4c</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72291000</link-uptime-ticks><link-uptime>747424</link-uptime><link-uptime-string>00008:15:37:04</link-uptime-string><rssi>-59</rssi><snr>14.0</snr><mcs-rx>12</mcs-rx><mcs-tx>9</mcs-tx><tx-per>0.0</tx-per><rx-per>44.4</rx-per><tx-power-index>22</tx-power-index><speed-rx>3800</speed-rx><speed-tx>2050</speed-tx><beam-index-rx>57</beam-index-rx><beam-azimuth-rx>-12</beam-azimuth-rx><beam-elevation-rx>0</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>57</beam-index-tx><beam-azimuth-tx>-12</beam-azimuth-tx><beam-elevation-tx>0</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>6853098</rx-ok><tx-ok>22227463</tx-ok><tx-fail>1990360</tx-fail><rx-fail>1125991</rx-fail><rx-hcs-fail>501</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>1126492</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>0</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>131</ifIndex><remote-assigned-name>679011</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>4</actual-local-sector-index><remote-mac-addr>02:02:6a:26:8f:80</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72292500</link-uptime-ticks><link-uptime>747409</link-uptime><link-uptime-string>00008:15:36:49</link-uptime-string><rssi>-59</rssi><snr>15.0</snr><mcs-rx>12</mcs-rx><mcs-tx>12</mcs-tx><tx-per>35.0</tx-per><rx-per>10.0</rx-per><tx-power-index>22</tx-power-index><speed-rx>3800</speed-rx><speed-tx>3800</speed-tx><beam-index-rx>36</beam-index-rx><beam-azimuth-rx>4</beam-azimuth-rx><beam-elevation-rx>-10</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>36</beam-index-tx><beam-azimuth-tx>4</beam-azimuth-tx><beam-elevation-tx>-10</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>6942843</rx-ok><tx-ok>24119226</tx-ok><tx-fail>3026756</tx-fail><rx-fail>3450772</rx-fail><rx-hcs-fail>157</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>3450929</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>0</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>133</ifIndex><remote-assigned-name>gnode-g</remote-assigned-name><actual-remote-sector-index>4</actual-remote-sector-index><actual-local-sector-index>1</actual-local-sector-index><remote-mac-addr>02:1a:24:c7:ab:2b</remote-mac-addr><local-role>initiator</local-role><link-uptime-ticks>72374000</link-uptime-ticks><link-uptime>746594</link-uptime><link-uptime-string>00008:15:23:14</link-uptime-string><rssi>-61</rssi><snr>12.0</snr><mcs-rx>10</mcs-rx><mcs-tx>11</mcs-tx><tx-per>2.3</tx-per><rx-per>0.0</rx-per><tx-power-index>26</tx-power-index><speed-rx>2500</speed-rx><speed-tx>3150</speed-tx><beam-index-rx>60</beam-index-rx><beam-azimuth-rx>0</beam-azimuth-rx><beam-elevation-rx>0</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>60</beam-index-tx><beam-azimuth-tx>0</beam-azimuth-tx><beam-elevation-tx>0</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>144228323</rx-ok><tx-ok>325037884</tx-ok><tx-fail>8137540</tx-fail><rx-fail>3172678</rx-fail><rx-hcs-fail>321</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>3172999</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>0</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><active><ifIndex>134</ifIndex><remote-assigned-name>gpop</remote-assigned-name><actual-remote-sector-index>1</actual-remote-sector-index><actual-local-sector-index>3</actual-local-sector-index><remote-mac-addr>02:00:00:3b:5c:18</remote-mac-addr><local-role>responder</local-role><link-uptime-ticks>98520500</link-uptime-ticks><link-uptime>485129</link-uptime><link-uptime-string>00005:14:45:29</link-uptime-string><rssi>-60</rssi><snr>14.0</snr><mcs-rx>11</mcs-rx><mcs-tx>11</mcs-tx><tx-per>1.1</tx-per><rx-per>2.8</rx-per><tx-power-index>24</tx-power-index><speed-rx>3150</speed-rx><speed-tx>3150</speed-tx><beam-index-rx>58</beam-index-rx><beam-azimuth-rx>-8</beam-azimuth-rx><beam-elevation-rx>0</beam-elevation-rx><active-tile-count-rx>1</active-tile-count-rx><beam-index-tx>58</beam-index-tx><beam-azimuth-tx>-8</beam-azimuth-tx><beam-elevation-tx>0</beam-elevation-tx><active-tile-count-tx>1</active-tile-count-tx><rx-ok>628756493</rx-ok><tx-ok>245365960</tx-ok><tx-fail>5480825</tx-fail><rx-fail>13631448</rx-fail><rx-hcs-fail>235</rx-hcs-fail><tx-failures>0</tx-failures><rx-failures>13631864</rx-failures><rx-drop-buf-size>0</rx-drop-buf-size><rx-drop-encryption-fail>181</rx-drop-encryption-fail><rx-drop-ra-mismatch>0</rx-drop-ra-mismatch><rx-drop-unexpected>0</rx-drop-unexpected></active><disconnected><local-sector><index>3</index><remote-sector><index>1</index><down-cause>LinkTrainingFailed</down-cause><last-update>2024-10-22 21:38:21</last-update></remote-sector></local-sector><remote-assigned-name>497691</remote-assigned-name></disconnected><disconnected><local-sector><index>3</index><remote-sector><index>1</index><down-cause>LinkTrainingFailed</down-cause><last-update>2024-10-22 21:38:37</last-update></remote-sector></local-sector><remote-assigned-name>526391</remote-assigned-name></disconnected><disconnected><local-sector><index>2</index><remote-sector><index>1</index><down-cause>LinkTrainingFailed</down-cause><last-update>2024-10-22 21:38:54</last-update></remote-sector></local-sector><remote-assigned-name>577481</remote-assigned-name></disconnected><disconnected><local-sector><index>2</index><remote-sector><index>1</index><down-cause>LinkTrainingFailed</down-cause><last-update>2024-10-22 21:37:34</last-update></remote-sector></local-sector><remote-assigned-name>586111</remote-assigned-name></disconnected><disconnected><local-sector><index>2</index><remote-sector><index>1</index><down-cause>LinkTrainingFailed</down-cause><last-update>2024-10-22 21:37:50</last-update></remote-sector></local-sector><remote-assigned-name>659751</remote-assigned-name></disconnected><disconnected><local-sector><index>1</index><remote-sector><index>1</index><down-cause>LinkTrainingFailed</down-cause><last-update>2024-10-22 21:38:06</last-update></remote-sector></local-sector><remote-assigned-name>701581</remote-assigned-name></disconnected></links></radio-common><radio-dn xmlns="http://siklu.com/yang/tg/radio/dn"><node-config><default-radio-profile><frequency>60480</frequency><polarity>even</polarity><tx-golay-index>1</tx-golay-index><rx-golay-index>1</rx-golay-index></default-radio-profile><is-pop-dn>false</is-pop-dn><sync-mode>gps-sync</sync-mode><sync-state><is-locked>true</is-locked><local-sync-state>synced</local-sync-state></sync-state><rf-sync><enabled>true</enabled><allow-free-running>false</allow-free-running><rf-sync-state><used>false</used><last-modified>1970-01-01 00:01:14</last-modified></rf-sync-state></rf-sync></node-config><sectors-config><sector><index>1</index><radio-profile><frequency>60480</frequency><polarity>odd</polarity><tx-golay-index>1</tx-golay-index><rx-golay-index>1</rx-golay-index></radio-profile></sector><sector><index>2</index><radio-profile><frequency>58320</frequency><polarity>odd</polarity><tx-golay-index>1</tx-golay-index><rx-golay-index>1</rx-golay-index></radio-profile></sector><sector><index>3</index><radio-profile><frequency>60480</frequency><polarity>odd</polarity><tx-golay-index>1</tx-golay-index><rx-golay-index>1</rx-golay-index></radio-profile></sector><sector><index>4</index><radio-profile><frequency>58320</frequency><polarity>odd</polarity><tx-golay-index>1</tx-golay-index><rx-golay-index>1</rx-golay-index></radio-profile></sector></sectors-config><links><configured><ifIndex>105</ifIndex><remote-assigned-name>488251</remote-assigned-name><local-sector><index>1</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>1</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>106</ifIndex><remote-assigned-name>497691</remote-assigned-name><local-sector><index>3</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>4</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>TriesDepletedWaitingForNextIgnitionPeriod</dn-link-state><disconnected-link><local-sector><index>3</index><remote-sector><index>1</index><down-cause>LinkTrainingFailed</down-cause></remote-sector></local-sector></disconnected-link><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>107</ifIndex><remote-assigned-name>498371</remote-assigned-name><local-sector><index>1</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>1</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>108</ifIndex><remote-assigned-name>498381</remote-assigned-name><local-sector><index>3</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>4</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>109</ifIndex><remote-assigned-name>526391</remote-assigned-name><local-sector><index>3</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>4</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>TriesDepletedWaitingForNextIgnitionPeriod</dn-link-state><disconnected-link><local-sector><index>3</index><remote-sector><index>1</index><down-cause>LinkTrainingFailed</down-cause></remote-sector></local-sector></disconnected-link><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>110</ifIndex><remote-assigned-name>551141</remote-assigned-name><local-sector><index>4</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>8</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>111</ifIndex><remote-assigned-name>552191</remote-assigned-name><local-sector><index>1</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>1</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>112</ifIndex><remote-assigned-name>553901</remote-assigned-name><local-sector><index>1</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>1</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>113</ifIndex><remote-assigned-name>556821</remote-assigned-name><local-sector><index>1</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>1</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>114</ifIndex><remote-assigned-name>559611</remote-assigned-name><local-sector><index>3</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>4</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>115</ifIndex><remote-assigned-name>567421</remote-assigned-name><local-sector><index>2</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>2</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>116</ifIndex><remote-assigned-name>567731</remote-assigned-name><local-sector><index>1</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>1</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>117</ifIndex><remote-assigned-name>570871</remote-assigned-name><local-sector><index>2</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>2</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>118</ifIndex><remote-assigned-name>570881</remote-assigned-name><local-sector><index>2</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>2</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>119</ifIndex><remote-assigned-name>576641</remote-assigned-name><local-sector><index>1</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>1</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>120</ifIndex><remote-assigned-name>577481</remote-assigned-name><local-sector><index>2</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>2</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>TriesDepletedWaitingForNextIgnitionPeriod</dn-link-state><disconnected-link><local-sector><index>2</index><remote-sector><index>1</index><down-cause>LinkTrainingFailed</down-cause></remote-sector></local-sector></disconnected-link><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>121</ifIndex><remote-assigned-name>579901</remote-assigned-name><local-sector><index>4</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>8</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>122</ifIndex><remote-assigned-name>582691</remote-assigned-name><local-sector><index>2</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>2</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>123</ifIndex><remote-assigned-name>586111</remote-assigned-name><local-sector><index>2</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>2</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>TriesDepletedWaitingForNextIgnitionPeriod</dn-link-state><disconnected-link><local-sector><index>2</index><remote-sector><index>1</index><down-cause>LinkTrainingFailed</down-cause></remote-sector></local-sector></disconnected-link><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>124</ifIndex><remote-assigned-name>588932</remote-assigned-name><local-sector><index>2</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>2</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>125</ifIndex><remote-assigned-name>608651</remote-assigned-name><local-sector><index>2</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>2</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>126</ifIndex><remote-assigned-name>611211</remote-assigned-name><local-sector><index>2</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>2</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>127</ifIndex><remote-assigned-name>659751</remote-assigned-name><local-sector><index>2</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>2</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>TriesDepletedWaitingForNextIgnitionPeriod</dn-link-state><disconnected-link><local-sector><index>2</index><remote-sector><index>1</index><down-cause>LinkTrainingFailed</down-cause></remote-sector></local-sector></disconnected-link><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>128</ifIndex><remote-assigned-name>662111</remote-assigned-name><local-sector><index>2</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>2</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>129</ifIndex><remote-assigned-name>669601</remote-assigned-name><local-sector><index>1</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>1</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>130</ifIndex><remote-assigned-name>672611</remote-assigned-name><local-sector><index>2</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>2</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>131</ifIndex><remote-assigned-name>679011</remote-assigned-name><local-sector><index>4</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>8</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>132</ifIndex><remote-assigned-name>701581</remote-assigned-name><local-sector><index>1</index></local-sector><control-superframe>unspecified</control-superframe><responder-node-type>cn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>1</local-sector-bitmap><remote-sector-bitmap>0</remote-sector-bitmap><dn-link-state>TriesDepletedWaitingForNextIgnitionPeriod</dn-link-state><disconnected-link><local-sector><index>1</index><remote-sector><index>1</index><down-cause>LinkTrainingFailed</down-cause></remote-sector></local-sector></disconnected-link><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured><configured><ifIndex>133</ifIndex><remote-assigned-name>gnode-g</remote-assigned-name><remote-sector><index>4</index></remote-sector><local-sector><index>1</index></local-sector><control-superframe>0</control-superframe><responder-node-type>dn</responder-node-type><admin-status>up</admin-status><local-sector-bitmap>1</local-sector-bitmap><remote-sector-bitmap>8</remote-sector-bitmap><dn-link-state>Connected</dn-link-state><tx-golay-index>unspecified</tx-golay-index><rx-golay-index>unspecified</rx-golay-index></configured></links><ignition-config><idle-timer>600</idle-timer><ignition-timer>240</ignition-timer><retry-count>2</retry-count></ignition-config></radio-dn><system xmlns="http://siklu.com/yang/tg/system"><name>gnode-a</name><contact/><reboot-needed xmlns="http://siklu.com/yang/tg/system">false</reboot-needed><location>AB.NW113.NODE.A - 53.302252,-3.553262</location><control><soft-watchdog-enabled>true</soft-watchdog-enabled></control><state><snmp-object-id>1.3.6.1.4.1.31926.35</snmp-object-id><snmp-services>2</snmp-services><product>MH-N366</product><date-and-time>2024-10-22 21:42:39</date-and-time><uptime>00017:00:25:34</uptime><uptime-hundredths-seconds>147033400</uptime-hundredths-seconds><is-rollback-active>true</is-rollback-active><banks-info><banks><number>0</number><software-version>not-exist / corrupted</software-version><status>passive</status><scheduled-to-switch>idle</scheduled-to-switch></banks><banks><number>1</number><software-version>2.3.0-3778-214041e90</software-version><status>active</status><scheduled-to-switch>idle</scheduled-to-switch></banks></banks-info><sw-upgrade-info><download-and-burning-state>failed</download-and-burning-state><url>file:///terragraph-upgrade-image-2.3.1-3781-145719c14.tar</url><download-file-error>Burn image to not running bank failed</download-file-error></sw-upgrade-info><gps><fix-mode>3D</fix-mode><fix-satellites-number>17</fix-satellites-number><accuracy>5.700</accuracy><latitude>53.3022216</latitude><longitude>-3.5533933</longitude><height-sea-level>24.200</height-sea-level><time>2024-10-22 20:42:41</time></gps><technician-file-creation>idle</technician-file-creation></state></system><user-bridge xmlns="http://siklu.com/yang/tg/user-bridge"><bridge><bridge-id>1</bridge-id><bridge-port><bridge-port-id>1</bridge-port-id><interface>eth1</interface><bridge-port-type>transparent</bridge-port-type></bridge-port><bridge-port><bridge-port-id>2</bridge-port-id><interface>eth2</interface><bridge-port-type>transparent</bridge-port-type></bridge-port><bridge-port><bridge-port-id>3</bridge-port-id><interface>eth3</interface><bridge-port-type>transparent</bridge-port-type></bridge-port><bridge-port><bridge-port-id>4</bridge-port-id><interface>host</interface><bridge-port-type>transparent</bridge-port-type></bridge-port><bridge-port><bridge-port-id>5</bridge-port-id><interface>rf</interface><bridge-port-type>transparent</bridge-port-type></bridge-port><bridge-port><bridge-port-id>6</bridge-port-id><interface>eth3</interface><bridge-port-type>q-in-q</bridge-port-type><s-vlan>156</s-vlan><c-vlan>123</c-vlan></bridge-port></bridge></user-bridge><user-management xmlns="http://siklu.com/yang/tg/user-management"><user><username>admin</username><password>$5$d0fJy1ImeHBqwKaF$ySyUbLzcSFbydxgBgvzUDLe2BaBS8BCjRKEaPZhAeG7</password></user></user-management></data></rpc-reply>'
    prefix_fields = dict(
        route='192.168.0.1',
        timestamp='2024-10-23 17:09:00'
    )
    output = TgParser(get_xml, prefix_fields)
    print(output)

